@@ -161,6 +161,13 @@ class BaseQuota(object):
                 raise
         return quota._info
 
+    def _network_quota_to_dict(self, network_quota):
+        if type(network_quota) is not dict:
+            dict_quota = network_quota.to_dict()
+        else:
+            dict_quota = network_quota
+        return {k: v for k, v in dict_quota.items() if v is not None}
+
     def get_network_quota(self, parsed_args):
         quota_class = (
             parsed_args.quota_class if 'quota_class' in parsed_args else False)
@@ -174,13 +181,11 @@ class BaseQuota(object):
             client = self.app.client_manager.network
             if default:
                 network_quota = client.get_quota_default(project)
-                if type(network_quota) is not dict:
-                    network_quota = network_quota.to_dict()
+                network_quota = self._network_quota_to_dict(network_quota)
             else:
                 network_quota = client.get_quota(project,
                                                  details=detail)
-                if type(network_quota) is not dict:
-                    network_quota = network_quota.to_dict()
+                network_quota = self._network_quota_to_dict(network_quota)
                 if detail:
                     # NOTE(slaweq): Neutron returns values with key "used" but
                     # Nova for example returns same data with key "in_use"
@@ -274,9 +279,18 @@ class ListQuota(command.Lister, BaseQuota):
         return parser
 
     def take_action(self, parsed_args):
-        projects = self.app.client_manager.identity.projects.list()
         result = []
-        project_ids = [getattr(p, 'id', '') for p in projects]
+        project_ids = []
+        if parsed_args.project is None:
+            for p in self.app.client_manager.identity.projects.list():
+                project_ids.append(getattr(p, 'id', ''))
+        else:
+            identity_client = self.app.client_manager.identity
+            project = utils.find_resource(
+                identity_client.projects,
+                parsed_args.project,
+            )
+            project_ids.append(getattr(project, 'id', ''))
 
         if parsed_args.compute:
             if parsed_args.detail:
@@ -516,6 +530,17 @@ class SetQuota(common.NetDetectionMixin, command.Command):
             metavar='<volume-type>',
             help=_('Set quotas for a specific <volume-type>'),
         )
+        parser.add_argument(
+            '--force',
+            action='store_true',
+            help=_('Force quota update (only supported by compute)')
+        )
+        parser.add_argument(
+            '--check-limit',
+            action='store_true',
+            help=_('Check quota limit when updating (only supported by '
+                   'network)')
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -529,6 +554,9 @@ class SetQuota(common.NetDetectionMixin, command.Command):
             if value is not None:
                 compute_kwargs[k] = value
 
+        if parsed_args.force:
+            compute_kwargs['force'] = True
+
         volume_kwargs = {}
         for k, v in VOLUME_QUOTAS.items():
             value = getattr(parsed_args, k, None)
@@ -539,6 +567,9 @@ class SetQuota(common.NetDetectionMixin, command.Command):
                 volume_kwargs[k] = value
 
         network_kwargs = {}
+        if parsed_args.check_limit:
+            network_kwargs['check_limit'] = True
+
         if self.app.client_manager.is_network_endpoint_enabled():
             for k, v in NETWORK_QUOTAS.items():
                 value = getattr(parsed_args, k, None)
