@@ -18,12 +18,12 @@
 
 import logging
 
+from openstack import utils as sdk_utils
 from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 
@@ -31,6 +31,25 @@ from openstackclient.i18n import _
 LOG = logging.getLogger(__name__)
 
 
+_aggregate_formatters = {
+    'Hosts': format_columns.ListColumn,
+    'Metadata': format_columns.DictColumn,
+    'hosts': format_columns.ListColumn,
+    'metadata': format_columns.DictColumn,
+}
+
+
+def _get_aggregate_columns(item):
+    # To maintain backwards compatibility we need to rename sdk props to
+    # whatever OSC was using before
+    column_map = {
+        'metadata': 'properties',
+    }
+    hidden_columns = ['links', 'location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item, column_map, hidden_columns)
+
+
 class AddAggregateHost(command.ShowOne):
     _description = _("Add host to aggregate")
 
@@ -49,26 +68,18 @@ class AddAggregateHost(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
 
-        aggregate = utils.find_resource(
-            compute_client.aggregates,
-            parsed_args.aggregate,
-        )
-        data = compute_client.aggregates.add_host(aggregate, parsed_args.host)
+        aggregate = compute_client.find_aggregate(
+            parsed_args.aggregate, ignore_missing=False)
 
-        info = {}
-        info.update(data._info)
+        aggregate = compute_client.add_host_to_aggregate(
+            aggregate.id, parsed_args.host)
 
-        # Special mapping for columns to make the output easier to read:
-        # 'metadata' --> 'properties'
-        info.update(
-            {
-                'hosts': format_columns.ListColumn(info.pop('hosts')),
-                'properties': format_columns.DictColumn(info.pop('metadata')),
-            },
-        )
-        return zip(*sorted(six.iteritems(info)))
+        display_columns, columns = _get_aggregate_columns(aggregate)
+        data = utils.get_item_properties(
+            aggregate, columns, formatters=_aggregate_formatters)
+        return (display_columns, data)
 
 
 class CreateAggregate(command.ShowOne):
@@ -90,42 +101,32 @@ class CreateAggregate(command.ShowOne):
             "--property",
             metavar="<key=value>",
             action=parseractions.KeyValueAction,
+            dest="properties",
             help=_("Property to add to this aggregate "
                    "(repeat option to set multiple properties)")
         )
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
 
-        info = {}
-        data = compute_client.aggregates.create(
-            parsed_args.name,
-            parsed_args.zone,
-        )
-        info.update(data._info)
+        attrs = {'name': parsed_args.name}
 
-        if parsed_args.property:
-            info.update(compute_client.aggregates.set_metadata(
-                data,
-                parsed_args.property,
-            )._info)
+        if parsed_args.zone:
+            attrs['availability_zone'] = parsed_args.zone
 
-        # Special mapping for columns to make the output easier to read:
-        # 'metadata' --> 'properties'
-        hosts = None
-        properties = None
-        if 'hosts' in info.keys():
-            hosts = format_columns.ListColumn(info.pop('hosts'))
-        if 'metadata' in info.keys():
-            properties = format_columns.DictColumn(info.pop('metadata'))
-        info.update(
-            {
-                'hosts': hosts,
-                'properties': properties,
-            },
-        )
-        return zip(*sorted(six.iteritems(info)))
+        aggregate = compute_client.create_aggregate(**attrs)
+
+        if parsed_args.properties:
+            aggregate = compute_client.set_aggregate_metadata(
+                aggregate.id,
+                parsed_args.properties,
+            )
+
+        display_columns, columns = _get_aggregate_columns(aggregate)
+        data = utils.get_item_properties(
+            aggregate, columns, formatters=_aggregate_formatters)
+        return (display_columns, data)
 
 
 class DeleteAggregate(command.Command):
@@ -142,13 +143,14 @@ class DeleteAggregate(command.Command):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
         result = 0
         for a in parsed_args.aggregate:
             try:
-                data = utils.find_resource(
-                    compute_client.aggregates, a)
-                compute_client.aggregates.delete(data.id)
+                aggregate = compute_client.find_aggregate(
+                    a, ignore_missing=False)
+                compute_client.delete_aggregate(
+                    aggregate.id, ignore_missing=False)
             except Exception as e:
                 result += 1
                 LOG.error(_("Failed to delete aggregate with name or "
@@ -176,27 +178,29 @@ class ListAggregate(command.Lister):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
 
-        data = compute_client.aggregates.list()
+        aggregates = list(compute_client.aggregates())
 
         if parsed_args.long:
             # Remove availability_zone from metadata because Nova doesn't
-            for d in data:
-                if 'availability_zone' in d.metadata:
-                    d.metadata.pop('availability_zone')
+            for aggregate in aggregates:
+                if 'availability_zone' in aggregate.metadata:
+                    aggregate.metadata.pop('availability_zone')
             # This is the easiest way to change column headers
             column_headers = (
                 "ID",
                 "Name",
                 "Availability Zone",
                 "Properties",
+                "Hosts",
             )
             columns = (
                 "ID",
                 "Name",
                 "Availability Zone",
                 "Metadata",
+                "Hosts",
             )
         else:
             column_headers = columns = (
@@ -205,14 +209,11 @@ class ListAggregate(command.Lister):
                 "Availability Zone",
             )
 
-        return (column_headers,
-                (utils.get_item_properties(
-                    s, columns,
-                    formatters={
-                        'Hosts': format_columns.ListColumn,
-                        'Metadata': format_columns.DictColumn,
-                    },
-                ) for s in data))
+        data = (
+            utils.get_item_properties(
+                s, columns, formatters=_aggregate_formatters
+            ) for s in aggregates)
+        return (column_headers, data)
 
 
 class RemoveAggregateHost(command.ShowOne):
@@ -233,29 +234,18 @@ class RemoveAggregateHost(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
 
-        aggregate = utils.find_resource(
-            compute_client.aggregates,
-            parsed_args.aggregate,
-        )
-        data = compute_client.aggregates.remove_host(
-            aggregate,
-            parsed_args.host,
-        )
+        aggregate = compute_client.find_aggregate(
+            parsed_args.aggregate, ignore_missing=False)
 
-        info = {}
-        info.update(data._info)
+        aggregate = compute_client.remove_host_from_aggregate(
+            aggregate.id, parsed_args.host)
 
-        # Special mapping for columns to make the output easier to read:
-        # 'metadata' --> 'properties'
-        info.update(
-            {
-                'hosts': format_columns.ListColumn(info.pop('hosts')),
-                'properties': format_columns.DictColumn(info.pop('metadata')),
-            },
-        )
-        return zip(*sorted(six.iteritems(info)))
+        display_columns, columns = _get_aggregate_columns(aggregate)
+        data = utils.get_item_properties(
+            aggregate, columns, formatters=_aggregate_formatters)
+        return (display_columns, data)
 
 
 class SetAggregate(command.Command):
@@ -282,12 +272,12 @@ class SetAggregate(command.Command):
             "--property",
             metavar="<key=value>",
             action=parseractions.KeyValueAction,
+            dest="properties",
             help=_("Property to set on <aggregate> "
                    "(repeat option to set multiple properties)")
         )
         parser.add_argument(
             "--no-property",
-            dest="no_property",
             action="store_true",
             help=_("Remove all properties from <aggregate> "
                    "(specify both --property and --no-property to "
@@ -297,11 +287,9 @@ class SetAggregate(command.Command):
 
     def take_action(self, parsed_args):
 
-        compute_client = self.app.client_manager.compute
-        aggregate = utils.find_resource(
-            compute_client.aggregates,
-            parsed_args.aggregate,
-        )
+        compute_client = self.app.client_manager.sdk_connection.compute
+        aggregate = compute_client.find_aggregate(
+            parsed_args.aggregate, ignore_missing=False)
 
         kwargs = {}
         if parsed_args.name:
@@ -309,29 +297,22 @@ class SetAggregate(command.Command):
         if parsed_args.zone:
             kwargs['availability_zone'] = parsed_args.zone
         if kwargs:
-            compute_client.aggregates.update(
-                aggregate,
-                kwargs
-            )
+            compute_client.update_aggregate(aggregate.id, **kwargs)
 
-        set_property = {}
+        properties = {}
         if parsed_args.no_property:
-            # NOTE(RuiChen): "availability_zone" is removed from response of
-            #                aggregate show and create commands, don't see it
-            #                anywhere, so pop it, avoid the unexpected server
-            #                exception(can't unset the availability zone from
-            #                aggregate metadata in nova).
-            set_property.update({key: None
-                                 for key in aggregate.metadata.keys()
-                                 if key != 'availability_zone'})
-        if parsed_args.property:
-            set_property.update(parsed_args.property)
+            # NOTE(RuiChen): "availability_zone" can not be unset from
+            # properties. It is already excluded from show and create output.
+            properties.update({
+                key: None for key in aggregate.metadata.keys()
+                if key != 'availability_zone'
+            })
 
-        if set_property:
-            compute_client.aggregates.set_metadata(
-                aggregate,
-                set_property
-            )
+        if parsed_args.properties:
+            properties.update(parsed_args.properties)
+
+        if properties:
+            compute_client.set_aggregate_metadata(aggregate.id, properties)
 
 
 class ShowAggregate(command.ShowOne):
@@ -348,31 +329,18 @@ class ShowAggregate(command.ShowOne):
 
     def take_action(self, parsed_args):
 
-        compute_client = self.app.client_manager.compute
-        data = utils.find_resource(
-            compute_client.aggregates,
-            parsed_args.aggregate,
-        )
+        compute_client = self.app.client_manager.sdk_connection.compute
+        aggregate = compute_client.find_aggregate(
+            parsed_args.aggregate, ignore_missing=False)
+
         # Remove availability_zone from metadata because Nova doesn't
-        if 'availability_zone' in data.metadata:
-            data.metadata.pop('availability_zone')
+        if 'availability_zone' in aggregate.metadata:
+            aggregate.metadata.pop('availability_zone')
 
-        # Special mapping for columns to make the output easier to read:
-        # 'metadata' --> 'properties'
-        data._info.update(
-            {
-                'hosts': format_columns.ListColumn(
-                    data._info.pop('hosts')
-                ),
-                'properties': format_columns.DictColumn(
-                    data._info.pop('metadata')
-                ),
-            },
-        )
-
-        info = {}
-        info.update(data._info)
-        return zip(*sorted(six.iteritems(info)))
+        display_columns, columns = _get_aggregate_columns(aggregate)
+        data = utils.get_item_properties(
+            aggregate, columns, formatters=_aggregate_formatters)
+        return (display_columns, data)
 
 
 class UnsetAggregate(command.Command):
@@ -388,21 +356,63 @@ class UnsetAggregate(command.Command):
         parser.add_argument(
             "--property",
             metavar="<key>",
-            action='append',
+            action="append",
+            default=[],
+            dest="properties",
             help=_("Property to remove from aggregate "
                    "(repeat option to remove multiple properties)")
         )
         return parser
 
     def take_action(self, parsed_args):
-        compute_client = self.app.client_manager.compute
-        aggregate = utils.find_resource(
-            compute_client.aggregates,
-            parsed_args.aggregate)
+        compute_client = self.app.client_manager.sdk_connection.compute
+        aggregate = compute_client.find_aggregate(
+            parsed_args.aggregate, ignore_missing=False)
 
-        unset_property = {}
-        if parsed_args.property:
-            unset_property.update({key: None for key in parsed_args.property})
-        if unset_property:
-            compute_client.aggregates.set_metadata(aggregate,
-                                                   unset_property)
+        properties = {key: None for key in parsed_args.properties}
+
+        if properties:
+            compute_client.set_aggregate_metadata(aggregate.id, properties)
+
+
+class CacheImageForAggregate(command.Command):
+    _description = _("Request image caching for aggregate")
+    # NOTE(gtema): According to stephenfin and dansmith there is no and will
+    # not be anything to return.
+
+    def get_parser(self, prog_name):
+        parser = super(CacheImageForAggregate, self).get_parser(prog_name)
+        parser.add_argument(
+            'aggregate',
+            metavar='<aggregate>',
+            help=_("Aggregate (name or ID)")
+        )
+        parser.add_argument(
+            'image',
+            metavar='<image>',
+            nargs='+',
+            help=_("Image ID to request caching for aggregate (name or ID). "
+                   "May be specified multiple times.")
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        compute_client = self.app.client_manager.sdk_connection.compute
+
+        if not sdk_utils.supports_microversion(compute_client, '2.81'):
+            msg = _(
+                'This operation requires server support for '
+                'API microversion 2.81'
+            )
+            raise exceptions.CommandError(msg)
+
+        aggregate = compute_client.find_aggregate(
+            parsed_args.aggregate, ignore_missing=False)
+
+        images = []
+        for img in parsed_args.image:
+            image = self.app.client_manager.sdk_connection.image.find_image(
+                img, ignore_missing=False)
+            images.append(image.id)
+
+        compute_client.aggregate_precache_images(aggregate.id, images)
