@@ -15,10 +15,11 @@
 
 """Compute v2 Server action implementations"""
 
+import importlib
+
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-from oslo_utils import importutils
 
 from openstackclient.i18n import _
 
@@ -71,12 +72,9 @@ class CreateServerBackup(command.ShowOne):
                 self.app.stderr.write('\rProgress: %s' % progress)
                 self.app.stderr.flush()
 
-        compute_client = self.app.client_manager.compute
+        compute_client = self.app.client_manager.sdk_connection.compute
 
-        server = utils.find_resource(
-            compute_client.servers,
-            parsed_args.server,
-        )
+        server = compute_client.find_server(parsed_args.server)
 
         # Set sane defaults as this API wants all mouths to be fed
         if parsed_args.name is None:
@@ -92,7 +90,7 @@ class CreateServerBackup(command.ShowOne):
         else:
             backup_rotation = parsed_args.rotate
 
-        compute_client.servers.backup(
+        compute_client.backup_server(
             server.id,
             backup_name,
             backup_type,
@@ -100,14 +98,11 @@ class CreateServerBackup(command.ShowOne):
         )
 
         image_client = self.app.client_manager.image
-        image = utils.find_resource(
-            image_client.images,
-            backup_name,
-        )
+        image = image_client.find_image(backup_name, ignore_missing=False)
 
         if parsed_args.wait:
             if utils.wait_for_status(
-                image_client.images.get,
+                image_client.get_image,
                 image.id,
                 callback=_show_progress,
             ):
@@ -122,7 +117,7 @@ class CreateServerBackup(command.ShowOne):
             info['properties'] = utils.format_dict(info.get('properties', {}))
         else:
             # Get the right image module to format the output
-            image_module = importutils.import_module(
+            image_module = importlib.import_module(
                 self.IMAGE_API_VERSIONS[
                     self.app.client_manager._api_version['image']
                 ]
