@@ -15,14 +15,14 @@
 
 """Identity v2 Token action implementations"""
 
-import six
+from osc_lib.command import command
+from osc_lib import exceptions
 
-from openstackclient.common import command
-from openstackclient.i18n import _  # noqa
+from openstackclient.i18n import _
 
 
 class IssueToken(command.ShowOne):
-    """Issue new token"""
+    _description = _("Issue new token")
 
     # scoped token is optional
     required_scope = False
@@ -32,15 +32,27 @@ class IssueToken(command.ShowOne):
         return parser
 
     def take_action(self, parsed_args):
+        auth_ref = self.app.client_manager.auth_ref
+        if not auth_ref:
+            raise exceptions.AuthorizationFailure(
+                "Only an authorized user may issue a new token.")
 
-        token = self.app.client_manager.auth_ref.service_catalog.get_token()
-        if 'tenant_id' in token:
-            token['project_id'] = token.pop('tenant_id')
-        return zip(*sorted(six.iteritems(token)))
+        data = {}
+        if auth_ref.auth_token:
+            data['id'] = auth_ref.auth_token
+        if auth_ref.expires:
+            datetime_obj = auth_ref.expires
+            expires_str = datetime_obj.strftime('%Y-%m-%dT%H:%M:%S%z')
+            data['expires'] = expires_str
+        if auth_ref.project_id:
+            data['project_id'] = auth_ref.project_id
+        if auth_ref.user_id:
+            data['user_id'] = auth_ref.user_id
+        return zip(*sorted(data.items()))
 
 
 class RevokeToken(command.Command):
-    """Revoke existing token"""
+    _description = _("Revoke existing token")
 
     def get_parser(self, prog_name):
         parser = super(RevokeToken, self).get_parser(prog_name)
