@@ -16,70 +16,75 @@
 """Identity v3 Consumer action implementations"""
 
 import logging
-import six
-import sys
 
-from cliff import command
-from cliff import lister
-from cliff import show
+from osc_lib.command import command
+from osc_lib import exceptions
+from osc_lib import utils
 
-from openstackclient.common import utils
+from openstackclient.i18n import _
 
 
-class CreateConsumer(show.ShowOne):
-    """Create new consumer"""
+LOG = logging.getLogger(__name__)
 
-    log = logging.getLogger(__name__ + '.CreateConsumer')
+
+class CreateConsumer(command.ShowOne):
+    _description = _("Create new consumer")
 
     def get_parser(self, prog_name):
         parser = super(CreateConsumer, self).get_parser(prog_name)
         parser.add_argument(
             '--description',
             metavar='<description>',
-            help='New consumer description',
+            help=_('New consumer description'),
         )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
         consumer = identity_client.oauth1.consumers.create(
             parsed_args.description
         )
         consumer._info.pop('links', None)
-        return zip(*sorted(six.iteritems(consumer._info)))
+        return zip(*sorted(consumer._info.items()))
 
 
 class DeleteConsumer(command.Command):
-    """Delete consumer"""
-
-    log = logging.getLogger(__name__ + '.DeleteConsumer')
+    _description = _("Delete consumer(s)")
 
     def get_parser(self, prog_name):
         parser = super(DeleteConsumer, self).get_parser(prog_name)
         parser.add_argument(
             'consumer',
             metavar='<consumer>',
-            help='Consumer to delete',
+            nargs='+',
+            help=_('Consumer(s) to delete'),
         )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
-        consumer = utils.find_resource(
-            identity_client.oauth1.consumers, parsed_args.consumer)
-        identity_client.oauth1.consumers.delete(consumer.id)
-        return
+        result = 0
+        for i in parsed_args.consumer:
+            try:
+                consumer = utils.find_resource(
+                    identity_client.oauth1.consumers, i)
+                identity_client.oauth1.consumers.delete(consumer.id)
+            except Exception as e:
+                result += 1
+                LOG.error(_("Failed to delete consumer with name or "
+                          "ID '%(consumer)s': %(e)s"), {'consumer': i, 'e': e})
+
+        if result > 0:
+            total = len(parsed_args.consumer)
+            msg = (_("%(result)s of %(total)s consumers failed "
+                   "to delete.") % {'result': result, 'total': total})
+            raise exceptions.CommandError(msg)
 
 
-class ListConsumer(lister.Lister):
-    """List consumers"""
-
-    log = logging.getLogger(__name__ + '.ListConsumer')
+class ListConsumer(command.Lister):
+    _description = _("List consumers")
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         columns = ('ID', 'Description')
         data = self.app.client_manager.identity.oauth1.consumers.list()
         return (columns,
@@ -90,26 +95,23 @@ class ListConsumer(lister.Lister):
 
 
 class SetConsumer(command.Command):
-    """Set consumer properties"""
-
-    log = logging.getLogger(__name__ + '.SetConsumer')
+    _description = _("Set consumer properties")
 
     def get_parser(self, prog_name):
         parser = super(SetConsumer, self).get_parser(prog_name)
         parser.add_argument(
             'consumer',
             metavar='<consumer>',
-            help='Consumer to modify',
+            help=_('Consumer to modify'),
         )
         parser.add_argument(
             '--description',
             metavar='<description>',
-            help='New consumer description',
+            help=_('New consumer description'),
         )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
         consumer = utils.find_resource(
             identity_client.oauth1.consumers, parsed_args.consumer)
@@ -117,34 +119,26 @@ class SetConsumer(command.Command):
         if parsed_args.description:
             kwargs['description'] = parsed_args.description
 
-        if not len(kwargs):
-            sys.stdout.write('Consumer not updated, no arguments present')
-            return
-
         consumer = identity_client.oauth1.consumers.update(
             consumer.id, **kwargs)
-        return
 
 
-class ShowConsumer(show.ShowOne):
-    """Display consumer details"""
-
-    log = logging.getLogger(__name__ + '.ShowConsumer')
+class ShowConsumer(command.ShowOne):
+    _description = _("Display consumer details")
 
     def get_parser(self, prog_name):
         parser = super(ShowConsumer, self).get_parser(prog_name)
         parser.add_argument(
             'consumer',
             metavar='<consumer>',
-            help='Consumer to display',
+            help=_('Consumer to display'),
         )
         return parser
 
     def take_action(self, parsed_args):
-        self.log.debug('take_action(%s)', parsed_args)
         identity_client = self.app.client_manager.identity
         consumer = utils.find_resource(
             identity_client.oauth1.consumers, parsed_args.consumer)
 
         consumer._info.pop('links', None)
-        return zip(*sorted(six.iteritems(consumer._info)))
+        return zip(*sorted(consumer._info.items()))
