@@ -31,7 +31,6 @@ from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.common import progressbar
-from openstackclient.common import sdk_utils
 from openstackclient.i18n import _
 from openstackclient.identity import common
 
@@ -99,13 +98,13 @@ _formatters = {
 
 
 def _get_member_columns(item):
-    # Trick sdk_utils to return URI attribute
     column_map = {
         'image_id': 'image_id'
     }
     hidden_columns = ['id', 'location', 'name']
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
-        item.to_dict(), column_map, hidden_columns)
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item.to_dict(), column_map, hidden_columns,
+    )
 
 
 def get_data_file(args):
@@ -490,6 +489,8 @@ class CreateImage(command.ShowOne):
                 parsed_args.name,
                 parsed_args.container_format,
                 parsed_args.disk_format,
+                visibility=kwargs.get('visibility', 'private'),
+                protected=True if parsed_args.protected else False
             )
             info = body['os-volume_upload_image']
             try:
@@ -615,6 +616,12 @@ class ListImage(command.Lister):
             default=None,
             help=_('Filter images based on tag.'),
         )
+        parser.add_argument(
+            '--hidden',
+            action='store_true',
+            default=False,
+            help=_('List hidden images'),
+        )
         parser.add_argument(
             '--long',
             action='store_true',
@@ -686,6 +693,8 @@ class ListImage(command.Lister):
                 parsed_args.project_domain,
             ).id
             kwargs['owner'] = project_id
+        if parsed_args.hidden:
+            kwargs['is_hidden'] = True
         if parsed_args.long:
             columns = (
                 'ID',
@@ -1003,19 +1012,44 @@ class SetImage(command.Command):
         membership_group = parser.add_mutually_exclusive_group()
         membership_group.add_argument(
             "--accept",
-            action="store_true",
+            action="store_const",
+            const="accepted",
+            dest="membership",
+            default=None,
             help=_("Accept the image membership"),
         )
         membership_group.add_argument(
             "--reject",
-            action="store_true",
+            action="store_const",
+            const="rejected",
+            dest="membership",
+            default=None,
             help=_("Reject the image membership"),
         )
         membership_group.add_argument(
             "--pending",
-            action="store_true",
+            action="store_const",
+            const="pending",
+            dest="membership",
+            default=None,
             help=_("Reset the image membership to 'pending'"),
         )
+
+        hidden_group = parser.add_mutually_exclusive_group()
+        hidden_group.add_argument(
+            "--hidden",
+            dest='hidden',
+            default=None,
+            action="store_true",
+            help=_("Hide the image"),
+        )
+        hidden_group.add_argument(
+            "--unhidden",
+            dest='hidden',
+            default=None,
+            action="store_false",
+            help=_("Unhide the image"),
+        )
         return parser
 
     def take_action(self, parsed_args):
@@ -1028,6 +1062,43 @@ class SetImage(command.Command):
                     _("ERROR: --%s was given, which is an Image v1 option"
                       " that is no longer supported in Image v2") % deadopt)
 
+        image = image_client.find_image(
+            parsed_args.image, ignore_missing=False,
+        )
+        project_id = None
+        if parsed_args.project:
+            project_id = common.find_project(
+                identity_client,
+                parsed_args.project,
+                parsed_args.project_domain,
+            ).id
+
+        # handle activation status changes
+
+        activation_status = None
+        if parsed_args.deactivate or parsed_args.activate:
+            if parsed_args.deactivate:
+                image_client.deactivate_image(image.id)
+                activation_status = "deactivated"
+            if parsed_args.activate:
+                image_client.reactivate_image(image.id)
+                activation_status = "activated"
+
+        # handle membership changes
+
+        if parsed_args.membership:
+            # If a specific project is not passed, assume we want to update
+            # our own membership
+            if not project_id:
+                project_id = self.app.client_manager.auth_ref.project_id
+            image_client.update_member(
+                image=image.id,
+                member=project_id,
+                status=parsed_args.membership,
+            )
+
+        # handle everything else
+
         kwargs = {}
         copy_attrs = ('architecture', 'container_format', 'disk_format',
                       'file', 'instance_id', 'kernel_id', 'locations',
@@ -1064,47 +1135,14 @@ class SetImage(command.Command):
             kwargs['visibility'] = 'community'
         if parsed_args.shared:
             kwargs['visibility'] = 'shared'
-        project_id = None
         if parsed_args.project:
-            project_id = common.find_project(
-                identity_client,
-                parsed_args.project,
-                parsed_args.project_domain,
-            ).id
+            # We already did the project lookup above
             kwargs['owner_id'] = project_id
-
-        image = image_client.find_image(parsed_args.image,
-                                        ignore_missing=False)
-
-        # image = utils.find_resource(
-        #     image_client.images, parsed_args.image)
-
-        activation_status = None
-        if parsed_args.deactivate:
-            image_client.deactivate_image(image.id)
-            activation_status = "deactivated"
-        if parsed_args.activate:
-            image_client.reactivate_image(image.id)
-            activation_status = "activated"
-
-        membership_group_args = ('accept', 'reject', 'pending')
-        membership_status = [status for status in membership_group_args
-                             if getattr(parsed_args, status)]
-        if membership_status:
-            # If a specific project is not passed, assume we want to update
-            # our own membership
-            if not project_id:
-                project_id = self.app.client_manager.auth_ref.project_id
-            # The mutually exclusive group of the arg parser ensure we have at
-            # most one item in the membership_status list.
-            if membership_status[0] != 'pending':
-                membership_status[0] += 'ed'  # Glance expects the past form
-            image_client.update_member(
-                image=image.id, member=project_id, status=membership_status[0])
-
         if parsed_args.tags:
             # Tags should be extended, but duplicates removed
             kwargs['tags'] = list(set(image.tags).union(set(parsed_args.tags)))
+        if parsed_args.hidden is not None:
+            kwargs['is_hidden'] = parsed_args.hidden
 
         try:
             image = image_client.update_image(image.id, **kwargs)
