@@ -13,14 +13,12 @@
 
 """IP Floating action implementations"""
 
-from osc_lib.command import command
 from osc_lib import utils
 from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 
 
 _formatters = {
@@ -29,17 +27,17 @@ _formatters = {
 
 
 def _get_network_columns(item):
-    column_map = {
-        'tenant_id': 'project_id',
-    }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    column_map = {}
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _get_columns(item):
     columns = list(item.keys())
-    if 'tenant_id' in columns:
-        columns.remove('tenant_id')
-        columns.append('project_id')
     return tuple(sorted(columns))
 
 
@@ -83,7 +81,7 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
 
     if parsed_args.dns_domain:
         attrs['dns_domain'] = parsed_args.dns_domain
@@ -94,7 +92,8 @@ def _get_attrs(client_manager, parsed_args):
     return attrs
 
 
-class CreateFloatingIP(common.NetworkAndComputeShowOne):
+class CreateFloatingIP(common.NetworkAndComputeShowOne,
+                       common.NeutronCommandWithExtraArgs):
     _description = _("Create floating IP")
 
     def update_parser_common(self, parser):
@@ -175,6 +174,8 @@ class CreateFloatingIP(common.NetworkAndComputeShowOne):
 
     def take_action_network(self, client, parsed_args):
         attrs = _get_attrs(self.app.client_manager, parsed_args)
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         with common.check_missing_extension_if_error(
                 self.app.client_manager.network, attrs):
             obj = client.create_ip(**attrs)
@@ -348,7 +349,6 @@ class ListFloatingIP(common.NetworkAndComputeLister):
                 parsed_args.project,
                 parsed_args.project_domain,
             )
-            query['tenant_id'] = project.id
             query['project_id'] = project.id
         if parsed_args.router is not None:
             router = network_client.find_router(parsed_args.router,
@@ -390,7 +390,7 @@ class ListFloatingIP(common.NetworkAndComputeLister):
                 ) for s in data))
 
 
-class SetFloatingIP(command.Command):
+class SetFloatingIP(common.NeutronCommandWithExtraArgs):
     _description = _("Set floating IP Properties")
 
     def get_parser(self, prog_name):
@@ -456,6 +456,9 @@ class SetFloatingIP(command.Command):
         if 'no_qos_policy' in parsed_args and parsed_args.no_qos_policy:
             attrs['qos_policy_id'] = None
 
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         if attrs:
             client.update_ip(obj, **attrs)
 
@@ -490,7 +493,7 @@ class ShowFloatingIP(common.NetworkAndComputeShowOne):
         return (columns, data)
 
 
-class UnsetFloatingIP(command.Command):
+class UnsetFloatingIP(common.NeutronCommandWithExtraArgs):
     _description = _("Unset floating IP Properties")
 
     def get_parser(self, prog_name):
@@ -526,6 +529,8 @@ class UnsetFloatingIP(command.Command):
             attrs['port_id'] = None
         if parsed_args.qos_policy:
             attrs['qos_policy_id'] = None
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
 
         if attrs:
             client.update_ip(obj, **attrs)
