@@ -15,15 +15,12 @@
 
 from cliff import columns as cliff_columns
 from osc_lib.cli import format_columns
-from osc_lib.command import command
-from osc_lib import exceptions
 from osc_lib import utils
 from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 
 
 class AdminStateColumn(cliff_columns.FormattableColumn):
@@ -41,7 +38,6 @@ _formatters = {
     'subnet_ids': format_columns.ListColumn,
     'admin_state_up': AdminStateColumn,
     'is_admin_state_up': AdminStateColumn,
-    'location': format_columns.DictColumn,
     'router:external': RouterExternalColumn,
     'is_router_external': RouterExternalColumn,
     'availability_zones': format_columns.ListColumn,
@@ -62,17 +58,19 @@ def _get_columns_network(item):
         'is_shared': 'shared',
         'ipv4_address_scope_id': 'ipv4_address_scope',
         'ipv6_address_scope_id': 'ipv6_address_scope',
-        'tenant_id': 'project_id',
         'tags': 'tags',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _get_columns_compute(item):
-    column_map = {
-        'tenant_id': 'project_id',
-    }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    column_map = {}
+    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
 
 
 def _get_attrs_network(client_manager, parsed_args):
@@ -100,8 +98,6 @@ def _get_attrs_network(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        # TODO(dtroyer): Remove tenant_id when we clean up the SDK refactor
-        attrs['tenant_id'] = project_id
         attrs['project_id'] = project_id
 
     # "network set" command doesn't support setting availability zone hints.
@@ -126,9 +122,6 @@ def _get_attrs_network(client_manager, parsed_args):
         attrs['is_default'] = False
     if parsed_args.default:
         attrs['is_default'] = True
-    if attrs.get('is_default') and not attrs.get('router:external'):
-        msg = _("Cannot set default for internal network")
-        raise exceptions.CommandError(msg)
     # Update Provider network options
     if parsed_args.provider_network_type:
         attrs['provider:network_type'] = parsed_args.provider_network_type
@@ -194,7 +187,8 @@ def _add_additional_network_options(parser):
 
 # TODO(sindhu): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class CreateNetwork(common.NetworkAndComputeShowOne):
+class CreateNetwork(common.NetworkAndComputeShowOne,
+                    common.NeutronCommandWithExtraArgs):
     _description = _("Create new network")
 
     def update_parser_common(self, parser):
@@ -339,6 +333,8 @@ class CreateNetwork(common.NetworkAndComputeShowOne):
             attrs['vlan_transparent'] = True
         if parsed_args.no_transparent_vlan:
             attrs['vlan_transparent'] = False
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         with common.check_missing_extension_if_error(
                 self.app.client_manager.network, attrs):
             obj = client.create_network(**attrs)
@@ -572,7 +568,6 @@ class ListNetwork(common.NetworkAndComputeLister):
                 parsed_args.project,
                 parsed_args.project_domain,
             )
-            args['tenant_id'] = project.id
             args['project_id'] = project.id
 
         if parsed_args.share:
@@ -628,7 +623,7 @@ class ListNetwork(common.NetworkAndComputeLister):
 
 # TODO(sindhu): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class SetNetwork(command.Command):
+class SetNetwork(common.NeutronCommandWithExtraArgs):
     _description = _("Set network properties")
 
     def get_parser(self, prog_name):
@@ -706,8 +701,7 @@ class SetNetwork(command.Command):
         default_router_grp.add_argument(
             '--default',
             action='store_true',
-            help=_("Set the network as the default external network "
-                   "(cannot be used with internal network).")
+            help=_("Set the network as the default external network")
         )
         default_router_grp.add_argument(
             '--no-default',
@@ -734,6 +728,8 @@ class SetNetwork(command.Command):
         obj = client.find_network(parsed_args.network, ignore_missing=False)
 
         attrs = _get_attrs_network(self.app.client_manager, parsed_args)
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         if attrs:
             with common.check_missing_extension_if_error(
                     self.app.client_manager.network, attrs):
@@ -767,7 +763,7 @@ class ShowNetwork(common.NetworkAndComputeShowOne):
         return (display_columns, data)
 
 
-class UnsetNetwork(command.Command):
+class UnsetNetwork(common.NeutronUnsetCommandWithExtraArgs):
     _description = _("Unset network properties")
 
     def get_parser(self, prog_name):
@@ -784,8 +780,9 @@ class UnsetNetwork(command.Command):
         client = self.app.client_manager.network
         obj = client.find_network(parsed_args.network, ignore_missing=False)
 
-        # NOTE: As of now, UnsetNetwork has no attributes which need
-        # to be updated by update_network().
+        attrs = self._parse_extra_properties(parsed_args.extra_properties)
+        if attrs:
+            client.update_network(obj, **attrs)
 
         # tags is a subresource and it needs to be updated separately.
         _tag.update_tags_for_unset(client, obj, parsed_args)
