@@ -25,10 +25,13 @@ LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    column_map = {
-        'tenant_id': 'project_id',
-    }
-    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    column_map = {}
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _format_check_resource_columns():
@@ -51,7 +54,7 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
     if parsed_args.check_resources:
         attrs['check_resources'] = True
 
