@@ -15,14 +15,12 @@
 
 import itertools
 
-from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.i18n import _
-from openstackclient.network import sdk_utils
-
+from openstackclient.network import common
 
 RULE_TYPE_BANDWIDTH_LIMIT = 'bandwidth-limit'
 RULE_TYPE_DSCP_MARKING = 'dscp-marking'
@@ -47,16 +45,14 @@ ACTION_SET = 'update'
 ACTION_SHOW = 'get'
 
 
-_formatters = {
-    'location': format_columns.DictColumn,
-}
-
-
 def _get_columns(item):
-    column_map = {
-        'tenant_id': 'project_id',
-    }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    column_map = {}
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _check_type_parameters(attrs, type, is_create):
@@ -90,9 +86,6 @@ def _get_attrs(network_client, parsed_args, is_create=False):
                    {'rule_id': parsed_args.id})
             raise exceptions.CommandError(msg)
     else:
-        if not parsed_args.type:
-            msg = _('"Create" rule command requires argument "type"')
-            raise exceptions.CommandError(msg)
         rule_type = parsed_args.type
     if parsed_args.max_kbps is not None:
         attrs['max_kbps'] = parsed_args.max_kbps
@@ -180,7 +173,8 @@ def _add_rule_arguments(parser):
     )
 
 
-class CreateNetworkQosRule(command.ShowOne):
+class CreateNetworkQosRule(command.ShowOne,
+                           common.NeutronCommandWithExtraArgs):
     _description = _("Create new Network QoS rule")
 
     def get_parser(self, prog_name):
@@ -194,6 +188,7 @@ class CreateNetworkQosRule(command.ShowOne):
         parser.add_argument(
             '--type',
             metavar='<type>',
+            required=True,
             choices=[RULE_TYPE_MINIMUM_BANDWIDTH,
                      RULE_TYPE_DSCP_MARKING,
                      RULE_TYPE_BANDWIDTH_LIMIT],
@@ -206,6 +201,8 @@ class CreateNetworkQosRule(command.ShowOne):
     def take_action(self, parsed_args):
         network_client = self.app.client_manager.network
         attrs = _get_attrs(network_client, parsed_args, is_create=True)
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         try:
             obj = _rule_action_call(
                 network_client, ACTION_CREATE, parsed_args.type)(
@@ -214,7 +211,7 @@ class CreateNetworkQosRule(command.ShowOne):
             msg = (_('Failed to create Network QoS rule: %(e)s') % {'e': e})
             raise exceptions.CommandError(msg)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return display_columns, data
 
 
@@ -293,7 +290,7 @@ class ListNetworkQosRule(command.Lister):
                 (_get_item_properties(s, columns) for s in data))
 
 
-class SetNetworkQosRule(command.Command):
+class SetNetworkQosRule(common.NeutronCommandWithExtraArgs):
     _description = _("Set Network QoS rule properties")
 
     def get_parser(self, prog_name):
@@ -320,6 +317,8 @@ class SetNetworkQosRule(command.Command):
             if not rule_type:
                 raise Exception('Rule not found')
             attrs = _get_attrs(network_client, parsed_args)
+            attrs.update(
+                self._parse_extra_properties(parsed_args.extra_properties))
             qos_id = attrs.pop('qos_policy_id')
             qos_rule = _rule_action_call(network_client, ACTION_FIND,
                                          rule_type)(attrs.pop('id'), qos_id)
@@ -364,5 +363,5 @@ class ShowNetworkQosRule(command.ShowOne):
                    {'rule': rule_id, 'e': e})
             raise exceptions.CommandError(msg)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return display_columns, data
