@@ -21,14 +21,18 @@ from osc_lib import utils
 
 from openstackclient.i18n import _
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
-
 
 LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, {})
+    column_map = {}
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 class CreateNetworkSegment(command.ShowOne,
