@@ -63,9 +63,13 @@ def _get_columns(item):
         'binding:vnic_type': 'binding_vnic_type',
         'is_admin_state_up': 'admin_state_up',
         'is_port_security_enabled': 'port_security_enabled',
-        'tenant_id': 'project_id',
     }
-    return utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 class JSONKeyValueAction(argparse.Action):
@@ -134,7 +138,7 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
 
     if parsed_args.disable_port_security:
         attrs['port_security_enabled'] = False
@@ -255,11 +259,12 @@ def _add_updatable_args(parser):
         metavar='<vnic-type>',
         choices=(
             'direct', 'direct-physical', 'macvtap',
-            'normal', 'baremetal', 'virtio-forwarder', 'vdpa'
+            'normal', 'baremetal', 'virtio-forwarder', 'vdpa', 'remote-managed'
         ),
         help=_(
             "VNIC type for this port (direct | direct-physical | "
-            "macvtap | normal | baremetal | virtio-forwarder | vdpa, "
+            "macvtap | normal | baremetal | virtio-forwarder | vdpa | "
+            "remote-managed, "
             "default: normal)"
         ),
     )
@@ -610,6 +615,13 @@ class ListPort(command.Lister):
             metavar='<name>',
             help=_("List ports according to their name")
         )
+        parser.add_argument(
+            '--security-group',
+            action='append',
+            dest='security_groups',
+            metavar='<security-group>',
+            help=_("List only ports associated with this security group")
+        )
         identity_common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--fixed-ip',
@@ -675,13 +687,14 @@ class ListPort(command.Lister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            filters['tenant_id'] = project_id
             filters['project_id'] = project_id
         if parsed_args.name:
             filters['name'] = parsed_args.name
         if parsed_args.fixed_ip:
             filters['fixed_ips'] = _prepare_filter_fixed_ips(
                 self.app.client_manager, parsed_args)
+        if parsed_args.security_groups:
+            filters['security_groups'] = parsed_args.security_groups
 
         _tag.get_tag_filtering_args(parsed_args, filters)
 
@@ -807,6 +820,17 @@ class SetPort(common.NeutronCommandWithExtraArgs):
                    "(Specify both --allowed-address and --no-allowed-address "
                    "to overwrite the current allowed-address pairs)")
         )
+        parser.add_argument(
+            '--extra-dhcp-option',
+            metavar='name=<name>[,value=<value>,ip-version={4,6}]',
+            default=[],
+            action=parseractions.MultiKeyValueCommaAction,
+            dest='extra_dhcp_options',
+            required_keys=['name'],
+            optional_keys=['value', "ip-version"],
+            help=_('Extra DHCP options to be assigned to this port: '
+                   'name=<name>[,value=<value>,ip-version={4,6}] '
+                   '(repeat option to set multiple extra DHCP options)'))
         parser.add_argument(
             '--data-plane-status',
             metavar='<status>',
@@ -869,6 +893,10 @@ class SetPort(common.NeutronCommandWithExtraArgs):
             attrs['allowed_address_pairs'].extend(
                 _convert_address_pairs(parsed_args)
             )
+
+        if parsed_args.extra_dhcp_options:
+            attrs["extra_dhcp_opts"] = _convert_extra_dhcp_options(parsed_args)
+
         if parsed_args.data_plane_status:
             attrs['data_plane_status'] = parsed_args.data_plane_status
 
@@ -969,6 +997,12 @@ class UnsetPort(common.NeutronUnsetCommandWithExtraArgs):
             action='store_true',
             help=_("Clear existing NUMA affinity policy")
         )
+        parser.add_argument(
+            '--host',
+            action='store_true',
+            default=False,
+            help=_("Clear host binding for the port.")
+        )
 
         _tag.add_tag_option_to_parser_for_unset(parser, _('port'))
 
@@ -1026,6 +1060,8 @@ class UnsetPort(common.NeutronUnsetCommandWithExtraArgs):
             attrs['data_plane_status'] = None
         if parsed_args.numa_policy:
             attrs['numa_affinity_policy'] = None
+        if parsed_args.host:
+            attrs['binding:host_id'] = None
 
         attrs.update(
             self._parse_extra_properties(parsed_args.extra_properties))
