@@ -16,7 +16,6 @@
 import argparse
 
 from cliff import columns as cliff_columns
-from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import utils
 from osc_lib.utils import tags as _tag
@@ -24,7 +23,6 @@ from osc_lib.utils import tags as _tag
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 from openstackclient.network import utils as network_utils
 
 
@@ -37,7 +35,6 @@ def _format_network_security_group_rules(sg_rules):
         for key in empty_keys:
             sg_rule.pop(key)
         sg_rule.pop('security_group_id', None)
-        sg_rule.pop('tenant_id', None)
         sg_rule.pop('project_id', None)
     return utils.format_list_of_dicts(sg_rules)
 
@@ -77,28 +74,33 @@ class ComputeSecurityGroupRulesColumn(cliff_columns.FormattableColumn):
 
 
 _formatters_network = {
-    'location': format_columns.DictColumn,
     'security_group_rules': NetworkSecurityGroupRulesColumn,
 }
 
 
 _formatters_compute = {
-    'location': format_columns.DictColumn,
     'rules': ComputeSecurityGroupRulesColumn,
 }
 
 
 def _get_columns(item):
+    # We still support Nova managed security groups, where we have tenant_id.
     column_map = {
         'security_group_rules': 'rules',
         'tenant_id': 'project_id',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class CreateSecurityGroup(common.NetworkAndComputeShowOne):
+class CreateSecurityGroup(common.NetworkAndComputeShowOne,
+                          common.NeutronCommandWithExtraArgs):
     _description = _("Create a new security group")
 
     def update_parser_common(self, parser):
@@ -120,6 +122,19 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
             metavar='<project>',
             help=self.enhance_help_neutron(_("Owner's project (name or ID)"))
         )
+        stateful_group = parser.add_mutually_exclusive_group()
+        stateful_group.add_argument(
+            "--stateful",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateful (Default)")
+        )
+        stateful_group.add_argument(
+            "--stateless",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateless")
+        )
         identity_common.add_project_domain_option_to_parser(
             parser, enhance_help=self.enhance_help_neutron)
         _tag.add_tag_option_to_parser_for_create(
@@ -138,6 +153,10 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
         attrs = {}
         attrs['name'] = parsed_args.name
         attrs['description'] = self._get_description(parsed_args)
+        if parsed_args.stateful:
+            attrs['stateful'] = True
+        if parsed_args.stateless:
+            attrs['stateful'] = False
         if parsed_args.project is not None:
             identity_client = self.app.client_manager.identity
             project_id = identity_common.find_project(
@@ -145,7 +164,9 @@ class CreateSecurityGroup(common.NetworkAndComputeShowOne):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            attrs['tenant_id'] = project_id
+            attrs['project_id'] = project_id
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
 
         # Create the security group and display the results.
         obj = client.create_security_group(**attrs)
@@ -248,7 +269,6 @@ class ListSecurityGroup(common.NetworkAndComputeLister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            filters['tenant_id'] = project_id
             filters['project_id'] = project_id
 
         _tag.get_tag_filtering_args(parsed_args, filters)
@@ -296,7 +316,8 @@ class ListSecurityGroup(common.NetworkAndComputeLister):
                 ) for s in data))
 
 
-class SetSecurityGroup(common.NetworkAndComputeCommand):
+class SetSecurityGroup(common.NetworkAndComputeCommand,
+                       common.NeutronCommandWithExtraArgs):
     _description = _("Set security group properties")
 
     def update_parser_common(self, parser):
@@ -315,6 +336,19 @@ class SetSecurityGroup(common.NetworkAndComputeCommand):
             metavar="<description>",
             help=_("New security group description")
         )
+        stateful_group = parser.add_mutually_exclusive_group()
+        stateful_group.add_argument(
+            "--stateful",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateful (Default)")
+        )
+        stateful_group.add_argument(
+            "--stateless",
+            action='store_true',
+            default=None,
+            help=_("Security group is stateless")
+        )
         return parser
 
     def update_parser_network(self, parser):
@@ -331,6 +365,12 @@ class SetSecurityGroup(common.NetworkAndComputeCommand):
             attrs['name'] = parsed_args.name
         if parsed_args.description is not None:
             attrs['description'] = parsed_args.description
+        if parsed_args.stateful:
+            attrs['stateful'] = True
+        if parsed_args.stateless:
+            attrs['stateful'] = False
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         # NOTE(rtheis): Previous behavior did not raise a CommandError
         # if there were no updates. Maintain this behavior and issue
         # the update.
