@@ -16,7 +16,6 @@
 import argparse
 import logging
 
-from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib import exceptions
 from osc_lib import utils
@@ -24,18 +23,11 @@ from osc_lib import utils
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
 from openstackclient.network import utils as network_utils
 
-
 LOG = logging.getLogger(__name__)
 
 
-_formatters = {
-    'location': format_columns.DictColumn,
-}
-
-
 def _format_security_group_rule_show(obj):
     data = network_utils.transform_compute_security_group_rule(obj)
     return zip(*sorted(data.items()))
@@ -79,10 +71,13 @@ def _format_remote_ip_prefix(rule):
 
 
 def _get_columns(item):
-    column_map = {
-        'tenant_id': 'project_id',
-    }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    column_map = {}
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _convert_to_lowercase(string):
@@ -110,7 +105,8 @@ def _is_icmp_protocol(protocol):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
+class CreateSecurityGroupRule(common.NetworkAndComputeShowOne,
+                              common.NeutronCommandWithExtraArgs):
     _description = _("Create a new security group rule")
 
     def update_parser_common(self, parser):
@@ -132,6 +128,12 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
             metavar="<group>",
             help=_("Remote security group (name or ID)"),
         )
+        if self.is_neutron:
+            remote_group.add_argument(
+                "--remote-address-group",
+                metavar="<group>",
+                help=_("Remote address group (name or ID)"),
+            )
 
         # NOTE(efried): The --dst-port, --protocol, and --proto options exist
         # for both nova-network and neutron, but differ slightly. For the sake
@@ -334,6 +336,11 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
                 parsed_args.remote_group,
                 ignore_missing=False
             ).id
+        elif parsed_args.remote_address_group is not None:
+            attrs['remote_address_group_id'] = client.find_address_group(
+                parsed_args.remote_address_group,
+                ignore_missing=False
+            ).id
         elif parsed_args.remote_ip is not None:
             attrs['remote_ip_prefix'] = parsed_args.remote_ip
         elif attrs['ethertype'] == 'IPv4':
@@ -348,12 +355,15 @@ class CreateSecurityGroupRule(common.NetworkAndComputeShowOne):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            attrs['tenant_id'] = project_id
+            attrs['project_id'] = project_id
+
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
 
         # Create and show the security group rule.
         obj = client.create_security_group_rule(**attrs)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
@@ -480,7 +490,7 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             action='store_true',
             default=False,
             help=self.enhance_help_neutron(
-                _("List additional fields in output"))
+                _("**Deprecated** This argument is no longer needed"))
         )
         return parser
 
@@ -510,15 +520,21 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             'Ethertype',
             'IP Range',
             'Port Range',
+            'Direction',
+            'Remote Security Group',
         )
-        if parsed_args.long:
-            column_headers = column_headers + ('Direction',)
-        column_headers = column_headers + ('Remote Security Group',)
+        if self.is_neutron:
+            column_headers = column_headers + ('Remote Address Group',)
         if parsed_args.group is None:
             column_headers = column_headers + ('Security Group',)
         return column_headers
 
     def take_action_network(self, client, parsed_args):
+        if parsed_args.long:
+            self.log.warning(_(
+                "The --long option has been deprecated and is no longer needed"
+            ))
+
         column_headers = self._get_column_headers(parsed_args)
         columns = (
             'id',
@@ -526,10 +542,10 @@ class ListSecurityGroupRule(common.NetworkAndComputeLister):
             'ether_type',
             'remote_ip_prefix',
             'port_range',
+            'direction',
+            'remote_group_id',
+            'remote_address_group_id',
         )
-        if parsed_args.long:
-            columns = columns + ('direction',)
-        columns = columns + ('remote_group_id',)
 
         # Get the security group rules using the requested query.
         query = {}
@@ -620,7 +636,7 @@ class ShowSecurityGroupRule(common.NetworkAndComputeShowOne):
         if not obj['remote_ip_prefix']:
             obj['remote_ip_prefix'] = _format_remote_ip_prefix(obj)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters=_formatters)
+        data = utils.get_item_properties(obj, columns)
         return (display_columns, data)
 
     def take_action_compute(self, client, parsed_args):
