@@ -26,8 +26,7 @@ from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
-from openstackclient.network import sdk_utils
-
+from openstackclient.network import common
 
 LOG = logging.getLogger(__name__)
 
@@ -138,14 +137,17 @@ def _get_columns(item):
     column_map = {
         'is_dhcp_enabled': 'enable_dhcp',
         'subnet_pool_id': 'subnetpool_id',
-        'tenant_id': 'project_id',
     }
     # Do not show this column when displaying a subnet
-    invisible_columns = ['use_default_subnet_pool']
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
+    invisible_columns = [
+        'location',
+        'use_default_subnet_pool',
+        'prefix_length'
+    ]
+    return utils.get_osc_show_columns_for_sdk_resource(
         item,
         column_map,
-        invisible_columns=invisible_columns
+        invisible_columns
     )
 
 
@@ -185,7 +187,7 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            attrs['tenant_id'] = project_id
+            attrs['project_id'] = project_id
         attrs['network_id'] = client.find_network(parsed_args.network,
                                                   ignore_missing=False).id
         if parsed_args.subnet_pool is not None:
@@ -250,7 +252,7 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class CreateSubnet(command.ShowOne):
+class CreateSubnet(command.ShowOne, common.NeutronCommandWithExtraArgs):
     _description = _("Create a subnet")
 
     def get_parser(self, prog_name):
@@ -373,6 +375,8 @@ class CreateSubnet(command.ShowOne):
     def take_action(self, parsed_args):
         client = self.app.client_manager.network
         attrs = _get_attrs(self.app.client_manager, parsed_args)
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         obj = client.create_subnet(**attrs)
         # tags cannot be set when created, so tags need to be set later.
         _tag.update_tags_for_set(client, obj, parsed_args)
@@ -488,6 +492,12 @@ class ListSubnet(command.Lister):
                    "(in CIDR notation) in output "
                    "e.g.: --subnet-range 10.10.0.0/16")
         )
+        parser.add_argument(
+            '--subnet-pool',
+            metavar='<subnet-pool>',
+            help=_("List only subnets which belong to a given subnet pool "
+                   "in output (Name or ID)")
+        )
         _tag.add_tag_filtering_option_to_parser(parser, _('subnets'))
         return parser
 
@@ -511,7 +521,6 @@ class ListSubnet(command.Lister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            filters['tenant_id'] = project_id
             filters['project_id'] = project_id
         if parsed_args.network:
             network_id = network_client.find_network(parsed_args.network,
@@ -523,6 +532,10 @@ class ListSubnet(command.Lister):
             filters['name'] = parsed_args.name
         if parsed_args.subnet_range:
             filters['cidr'] = parsed_args.subnet_range
+        if parsed_args.subnet_pool:
+            subnetpool_id = network_client.find_subnet_pool(
+                parsed_args.subnet_pool, ignore_missing=False).id
+            filters['subnetpool_id'] = subnetpool_id
         _tag.get_tag_filtering_args(parsed_args, filters)
         data = network_client.subnets(**filters)
 
@@ -545,7 +558,7 @@ class ListSubnet(command.Lister):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class SetSubnet(command.Command):
+class SetSubnet(common.NeutronCommandWithExtraArgs):
     _description = _("Set subnet properties")
 
     def get_parser(self, prog_name):
@@ -630,6 +643,8 @@ class SetSubnet(command.Command):
             attrs['allocation_pools'] = []
         if 'service_types' in attrs:
             attrs['service_types'] += obj.service_types
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
         if attrs:
             client.update_subnet(obj, **attrs)
         # tags is a subresource and it needs to be updated separately.
@@ -657,7 +672,7 @@ class ShowSubnet(command.ShowOne):
         return (display_columns, data)
 
 
-class UnsetSubnet(command.Command):
+class UnsetSubnet(common.NeutronUnsetCommandWithExtraArgs):
     _description = _("Unset subnet properties")
 
     def get_parser(self, prog_name):
@@ -744,6 +759,9 @@ class UnsetSubnet(command.Command):
             _update_arguments(attrs['service_types'],
                               parsed_args.service_types,
                               'service-type')
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         if attrs:
             client.update_subnet(obj, **attrs)
 
