@@ -10,6 +10,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import itertools
 import json
 import time
 import uuid
@@ -346,6 +347,14 @@ class ServerTests(common.ComputeTestCase):
             #                DevStack without cells.
             self.skipTest("No Network service present")
 
+        def _chain_addresses(addresses):
+            # Flatten a dict of lists mapping network names to IP addresses,
+            # returning only the IP addresses
+            #
+            # >>> _chain_addresses({'private': ['10.1.0.32', '172.24.5.41']})
+            # ['10.1.0.32', '172.24.5.41']
+            return itertools.chain(*[*addresses.values()])
+
         cmd_output = self.server_create()
         name = cmd_output['name']
         self.wait_for_status(name, "ACTIVE")
@@ -387,7 +396,7 @@ class ServerTests(common.ComputeTestCase):
                 'server show -f json ' +
                 name
             ))
-            if floating_ip not in cmd_output['addresses']:
+            if floating_ip not in _chain_addresses(cmd_output['addresses']):
                 # Hang out for a bit and try again
                 print('retrying floating IP check')
                 wait_time += 10
@@ -397,7 +406,7 @@ class ServerTests(common.ComputeTestCase):
 
         self.assertIn(
             floating_ip,
-            cmd_output['addresses'],
+            _chain_addresses(cmd_output['addresses']),
         )
 
         # detach ip
@@ -417,7 +426,7 @@ class ServerTests(common.ComputeTestCase):
                 'server show -f json ' +
                 name
             ))
-            if floating_ip in cmd_output['addresses']:
+            if floating_ip in _chain_addresses(cmd_output['addresses']):
                 # Hang out for a bit and try again
                 print('retrying floating IP check')
                 wait_time += 10
@@ -431,7 +440,7 @@ class ServerTests(common.ComputeTestCase):
         ))
         self.assertNotIn(
             floating_ip,
-            cmd_output['addresses'],
+            _chain_addresses(cmd_output['addresses']),
         )
 
     def test_server_reboot(self):
@@ -565,7 +574,90 @@ class ServerTests(common.ComputeTestCase):
             cmd_output['status'],
         )
 
-    def test_server_boot_with_bdm_snapshot(self):
+    def _test_server_boot_with_bdm_volume(self, use_legacy):
+        """Test server create from volume, server delete"""
+        # get volume status wait function
+        volume_wait_for = volume_common.BaseVolumeTests.wait_for_status
+
+        # create source empty volume
+        volume_name = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'volume create -f json ' +
+            '--size 1 ' +
+            volume_name
+        ))
+        volume_id = cmd_output["id"]
+        self.assertIsNotNone(volume_id)
+        self.addCleanup(self.openstack, 'volume delete ' + volume_name)
+        self.assertEqual(volume_name, cmd_output['name'])
+        volume_wait_for("volume", volume_name, "available")
+
+        if use_legacy:
+            bdm_arg = f'--block-device-mapping vdb={volume_name}'
+        else:
+            bdm_arg = (
+                f'--block-device '
+                f'device_name=vdb,source_type=volume,boot_index=1,'
+                f'uuid={volume_id}'
+            )
+
+        # create server
+        server_name = uuid.uuid4().hex
+        server = json.loads(self.openstack(
+            'server create -f json ' +
+            '--flavor ' + self.flavor_name + ' ' +
+            '--image ' + self.image_name + ' ' +
+            bdm_arg + ' ' +
+            self.network_arg + ' ' +
+            '--wait ' +
+            server_name
+        ))
+        self.assertIsNotNone(server["id"])
+        self.addCleanup(self.openstack, 'server delete --wait ' + server_name)
+        self.assertEqual(
+            server_name,
+            server['name'],
+        )
+
+        # check server volumes_attached, format is
+        # {"volumes_attached": "id='2518bc76-bf0b-476e-ad6b-571973745bb5'",}
+        cmd_output = json.loads(self.openstack(
+            'server show -f json ' +
+            server_name
+        ))
+        volumes_attached = cmd_output['volumes_attached']
+        self.assertIsNotNone(volumes_attached)
+
+        # check volumes
+        cmd_output = json.loads(self.openstack(
+            'volume show -f json ' +
+            volume_name
+        ))
+        attachments = cmd_output['attachments']
+        self.assertEqual(
+            1,
+            len(attachments),
+        )
+        self.assertEqual(
+            server['id'],
+            attachments[0]['server_id'],
+        )
+        self.assertEqual(
+            "in-use",
+            cmd_output['status'],
+        )
+
+    def test_server_boot_with_bdm_volume(self):
+        """Test server create from image with bdm volume, server delete"""
+        self._test_server_boot_with_bdm_volume(use_legacy=False)
+
+    # TODO(stephenfin): Remove when we drop support for the
+    # '--block-device-mapping' option
+    def test_server_boot_with_bdm_volume_legacy(self):
+        """Test server create from image with bdm volume, server delete"""
+        self._test_server_boot_with_bdm_volume(use_legacy=True)
+
+    def _test_server_boot_with_bdm_snapshot(self, use_legacy):
         """Test server create from image with bdm snapshot, server delete"""
         # get volume status wait function
         volume_wait_for = volume_common.BaseVolumeTests.wait_for_status
@@ -579,12 +671,8 @@ class ServerTests(common.ComputeTestCase):
             empty_volume_name
         ))
         self.assertIsNotNone(cmd_output["id"])
-        self.addCleanup(self.openstack,
-                        'volume delete ' + empty_volume_name)
-        self.assertEqual(
-            empty_volume_name,
-            cmd_output['name'],
-        )
+        self.addCleanup(self.openstack, 'volume delete ' + empty_volume_name)
+        self.assertEqual(empty_volume_name, cmd_output['name'])
         volume_wait_for("volume", empty_volume_name, "available")
 
         # create snapshot of source empty volume
@@ -594,7 +682,8 @@ class ServerTests(common.ComputeTestCase):
             '--volume ' + empty_volume_name + ' ' +
             empty_snapshot_name
         ))
-        self.assertIsNotNone(cmd_output["id"])
+        empty_snapshot_id = cmd_output["id"]
+        self.assertIsNotNone(empty_snapshot_id)
         # Deleting volume snapshot take time, so we need to wait until the
         # snapshot goes. Entries registered by self.addCleanup will be called
         # in the reverse order, so we need to register wait_for_delete first.
@@ -608,14 +697,26 @@ class ServerTests(common.ComputeTestCase):
         )
         volume_wait_for("volume snapshot", empty_snapshot_name, "available")
 
+        if use_legacy:
+            bdm_arg = (
+                f'--block-device-mapping '
+                f'vdb={empty_snapshot_name}:snapshot:1:true'
+            )
+        else:
+            bdm_arg = (
+                f'--block-device '
+                f'device_name=vdb,uuid={empty_snapshot_id},'
+                f'source_type=snapshot,volume_size=1,'
+                f'delete_on_termination=true,boot_index=1'
+            )
+
         # create server with bdm snapshot
         server_name = uuid.uuid4().hex
         server = json.loads(self.openstack(
             'server create -f json ' +
             '--flavor ' + self.flavor_name + ' ' +
             '--image ' + self.image_name + ' ' +
-            '--block-device-mapping '
-            'vdb=' + empty_snapshot_name + ':snapshot:1:true ' +
+            bdm_arg + ' ' +
             self.network_arg + ' ' +
             '--wait ' +
             server_name
@@ -672,7 +773,17 @@ class ServerTests(common.ComputeTestCase):
             # the attached volume had been deleted
             pass
 
-    def test_server_boot_with_bdm_image(self):
+    def test_server_boot_with_bdm_snapshot(self):
+        """Test server create from image with bdm snapshot, server delete"""
+        self._test_server_boot_with_bdm_snapshot(use_legacy=False)
+
+    # TODO(stephenfin): Remove when we drop support for the
+    # '--block-device-mapping' option
+    def test_server_boot_with_bdm_snapshot_legacy(self):
+        """Test server create from image with bdm snapshot, server delete"""
+        self._test_server_boot_with_bdm_snapshot(use_legacy=True)
+
+    def _test_server_boot_with_bdm_image(self, use_legacy):
         # Tests creating a server where the root disk is backed by the given
         # --image but a --block-device-mapping with type=image is provided so
         # that the compute service creates a volume from that image and
@@ -680,6 +791,32 @@ class ServerTests(common.ComputeTestCase):
         # marked as delete_on_termination=True so it will be automatically
         # deleted when the server is deleted.
 
+        if use_legacy:
+            # This means create a 1GB volume from the specified image, attach
+            # it to the server at /dev/vdb and delete the volume when the
+            # server is deleted.
+            bdm_arg = (
+                f'--block-device-mapping '
+                f'vdb={self.image_name}:image:1:true '
+            )
+        else:
+            # get image ID
+            cmd_output = json.loads(self.openstack(
+                'image show -f json ' +
+                self.image_name
+            ))
+            image_id = cmd_output['id']
+
+            # This means create a 1GB volume from the specified image, attach
+            # it to the server at /dev/vdb and delete the volume when the
+            # server is deleted.
+            bdm_arg = (
+                f'--block-device '
+                f'device_name=vdb,uuid={image_id},'
+                f'source_type=image,volume_size=1,'
+                f'delete_on_termination=true,boot_index=1'
+            )
+
         # create server with bdm type=image
         # NOTE(mriedem): This test is a bit unrealistic in that specifying the
         # same image in the block device as the --image option does not really
@@ -691,11 +828,7 @@ class ServerTests(common.ComputeTestCase):
             'server create -f json ' +
             '--flavor ' + self.flavor_name + ' ' +
             '--image ' + self.image_name + ' ' +
-            '--block-device-mapping '
-            # This means create a 1GB volume from the specified image, attach
-            # it to the server at /dev/vdb and delete the volume when the
-            # server is deleted.
-            'vdb=' + self.image_name + ':image:1:true ' +
+            bdm_arg + ' ' +
             self.network_arg + ' ' +
             '--wait ' +
             server_name
@@ -759,6 +892,14 @@ class ServerTests(common.ComputeTestCase):
             # the attached volume had been deleted
             pass
 
+    def test_server_boot_with_bdm_image(self):
+        self._test_server_boot_with_bdm_image(use_legacy=False)
+
+    # TODO(stephenfin): Remove when we drop support for the
+    # '--block-device-mapping' option
+    def test_server_boot_with_bdm_image_legacy(self):
+        self._test_server_boot_with_bdm_image(use_legacy=True)
+
     def test_boot_from_volume(self):
         # Tests creating a server using --image and --boot-from-volume where
         # the compute service will create a root volume of the specified size
@@ -856,8 +997,7 @@ class ServerTests(common.ComputeTestCase):
         server = json.loads(self.openstack(
             'server show -f json ' + server_name
         ))
-        self.assertIsNotNone(server['addresses'])
-        self.assertEqual('', server['addresses'])
+        self.assertEqual({}, server['addresses'])
 
     def test_server_create_with_security_group(self):
         """Test server create with security group ID and name"""
@@ -931,3 +1071,182 @@ class ServerTests(common.ComputeTestCase):
             # networks and the test didn't specify a specific network.
             self.assertNotIn('nics are required after microversion 2.36',
                              e.stderr)
+
+    def test_server_add_remove_network(self):
+        name = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'server create -f json ' +
+            '--network private ' +
+            '--flavor ' + self.flavor_name + ' ' +
+            '--image ' + self.image_name + ' ' +
+            '--wait ' +
+            name
+        ))
+
+        self.assertIsNotNone(cmd_output['id'])
+        self.assertEqual(name, cmd_output['name'])
+        self.addCleanup(self.openstack, 'server delete --wait ' + name)
+
+        # add network and check 'public' is in server show
+        self.openstack(
+            'server add network ' + name + ' public')
+
+        wait_time = 0
+        while wait_time < 60:
+            cmd_output = json.loads(self.openstack(
+                'server show -f json ' + name
+            ))
+            if 'public' not in cmd_output['addresses']:
+                # Hang out for a bit and try again
+                print('retrying add network check')
+                wait_time += 10
+                time.sleep(10)
+            else:
+                break
+        addresses = cmd_output['addresses']
+        self.assertIn('public', addresses)
+
+        # remove network and check 'public' is not in server show
+        self.openstack('server remove network ' + name + ' public')
+
+        wait_time = 0
+        while wait_time < 60:
+            cmd_output = json.loads(self.openstack(
+                'server show -f json ' + name
+            ))
+            if 'public' in cmd_output['addresses']:
+                # Hang out for a bit and try again
+                print('retrying remove network check')
+                wait_time += 10
+                time.sleep(10)
+            else:
+                break
+
+        addresses = cmd_output['addresses']
+        self.assertNotIn('public', addresses)
+
+    def test_server_add_remove_port(self):
+        name = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'server create -f json ' +
+            '--network private ' +
+            '--flavor ' + self.flavor_name + ' ' +
+            '--image ' + self.image_name + ' ' +
+            '--wait ' +
+            name
+        ))
+
+        self.assertIsNotNone(cmd_output['id'])
+        self.assertEqual(name, cmd_output['name'])
+        self.addCleanup(self.openstack, 'server delete --wait ' + name)
+
+        # create port, record one of its ip address
+        port_name = uuid.uuid4().hex
+
+        cmd_output = json.loads(self.openstack(
+            'port list -f json'
+        ))
+        self.assertNotIn(port_name, cmd_output)
+
+        cmd_output = json.loads(self.openstack(
+            'port create -f json ' +
+            '--network private ' + port_name
+        ))
+        self.assertIsNotNone(cmd_output['id'])
+        ip_address = cmd_output['fixed_ips'][0]['ip_address']
+        self.addCleanup(self.openstack, 'port delete ' + port_name)
+
+        # add port to server, assert the ip address of the port appears
+        self.openstack('server add port ' + name + ' ' + port_name)
+
+        wait_time = 0
+        while wait_time < 60:
+            cmd_output = json.loads(self.openstack(
+                'server show -f json ' + name
+            ))
+            if ip_address not in cmd_output['addresses']['private']:
+                # Hang out for a bit and try again
+                print('retrying add port check')
+                wait_time += 10
+                time.sleep(10)
+            else:
+                break
+        addresses = cmd_output['addresses']['private']
+        self.assertIn(ip_address, addresses)
+
+        # remove port, assert the ip address of the port doesn't appear
+        self.openstack('server remove port ' + name + ' ' + port_name)
+
+        wait_time = 0
+        while wait_time < 60:
+            cmd_output = json.loads(self.openstack(
+                'server show -f json ' + name
+            ))
+            if ip_address in cmd_output['addresses']['private']:
+                # Hang out for a bit and try again
+                print('retrying add port check')
+                wait_time += 10
+                time.sleep(10)
+            else:
+                break
+        addresses = cmd_output['addresses']['private']
+        self.assertNotIn(ip_address, addresses)
+
+    def test_server_add_remove_volume(self):
+        volume_wait_for = volume_common.BaseVolumeTests.wait_for_status
+
+        name = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'server create -f json ' +
+            '--network private ' +
+            '--flavor ' + self.flavor_name + ' ' +
+            '--image ' + self.image_name + ' ' +
+            '--wait ' +
+            name
+        ))
+
+        self.assertIsNotNone(cmd_output['id'])
+        self.assertEqual(name, cmd_output['name'])
+        self.addCleanup(self.openstack, 'server delete --wait ' + name)
+        server_id = cmd_output['id']
+
+        volume_name = uuid.uuid4().hex
+        cmd_output = json.loads(self.openstack(
+            'volume create -f json ' +
+            '--size 1 ' +
+            volume_name
+        ))
+
+        self.assertIsNotNone(cmd_output['id'])
+        self.assertEqual(volume_name, cmd_output['name'])
+        volume_wait_for('volume', volume_name, 'available')
+        self.addCleanup(self.openstack, 'volume delete ' + volume_name)
+        volume_id = cmd_output['id']
+
+        cmd_output = json.loads(self.openstack(
+            'server add volume -f json ' +
+            name + ' ' +
+            volume_name + ' ' +
+            '--tag bar'
+        ))
+
+        self.assertIsNotNone(cmd_output['ID'])
+        self.assertEqual(server_id, cmd_output['Server ID'])
+        self.assertEqual(volume_id, cmd_output['Volume ID'])
+        volume_attachment_id = cmd_output['ID']
+
+        cmd_output = json.loads(self.openstack(
+            'server volume list -f json ' +
+            name
+        ))
+
+        self.assertEqual(volume_attachment_id, cmd_output[0]['ID'])
+        self.assertEqual(server_id, cmd_output[0]['Server ID'])
+        self.assertEqual(volume_id, cmd_output[0]['Volume ID'])
+
+        volume_wait_for('volume', volume_name, 'in-use')
+        self.openstack('server remove volume ' + name + ' ' + volume_name)
+        volume_wait_for('volume', volume_name, 'available')
+
+        raw_output = self.openstack('server volume list ' + name)
+        self.assertEqual('\n', raw_output)
