@@ -120,14 +120,14 @@ class NetworkTests(common.NetworkTagTests):
             cmd_output["description"],
         )
         self.assertEqual(
-            'UP',
+            True,
             cmd_output["admin_state_up"],
         )
         self.assertFalse(
             cmd_output["shared"],
         )
         self.assertEqual(
-            'Internal',
+            False,
             cmd_output["router:external"],
         )
 
@@ -231,12 +231,12 @@ class NetworkTests(common.NetworkTagTests):
             )
             # Check the default values
             self.assertEqual(
-                'UP',
+                True,
                 cmd_output["admin_state_up"],
             )
             self.assertFalse(cmd_output["shared"])
             self.assertEqual(
-                'Internal',
+                False,
                 cmd_output["router:external"],
             )
             self.assertFalse(cmd_output["is_default"])
@@ -266,7 +266,7 @@ class NetworkTests(common.NetworkTagTests):
                 cmd_output["description"],
             )
             self.assertEqual(
-                'DOWN',
+                False,
                 cmd_output["admin_state_up"],
             )
             self.assertTrue(cmd_output["shared"])
@@ -335,6 +335,8 @@ class NetworkTests(common.NetworkTagTests):
     def test_network_dhcp_agent(self):
         if not self.haz_network:
             self.skipTest("No Network service present")
+        if not self.is_extension_enabled("dhcp_agent_scheduler"):
+            self.skipTest("No dhcp_agent_scheduler extension present")
 
         name1 = uuid.uuid4().hex
         cmd_output1 = json.loads(self.openstack(
@@ -398,12 +400,12 @@ class NetworkTests(common.NetworkTagTests):
             cmd_output["description"],
         )
         self.assertEqual(
-            'UP',
+            True,
             cmd_output["admin_state_up"],
         )
         self.assertFalse(cmd_output["shared"])
         self.assertEqual(
-            'Internal',
+            False,
             cmd_output["router:external"],
         )
 
@@ -432,12 +434,12 @@ class NetworkTests(common.NetworkTagTests):
             cmd_output["description"],
         )
         self.assertEqual(
-            'DOWN',
+            False,
             cmd_output["admin_state_up"],
         )
         self.assertTrue(cmd_output["shared"])
         self.assertEqual(
-            'External',
+            True,
             cmd_output["router:external"],
         )
         self.assertFalse(cmd_output["is_default"])
