@@ -11,7 +11,6 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
-#
 
 import copy
 import io
@@ -19,7 +18,6 @@ import os
 import tempfile
 from unittest import mock
 
-from cinderclient import api_versions
 from openstack import exceptions as sdk_exceptions
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
@@ -27,41 +25,24 @@ from osc_lib import exceptions
 from openstackclient.image.v2 import image
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
 from openstackclient.tests.unit.image.v2 import fakes as image_fakes
-from openstackclient.tests.unit.volume.v3 import fakes as volume_fakes
 
 
-class TestImage(image_fakes.TestImagev2, volume_fakes.TestVolume):
+class TestImage(image_fakes.TestImagev2):
 
     def setUp(self):
         super(TestImage, self).setUp()
 
-        # Get shortcuts to the Mocks in image client
-        # SDK proxy mock
-        self.app.client_manager.image = mock.Mock()
+        # Get shortcuts to mocked image client
         self.client = self.app.client_manager.image
 
-        self.client.remove_member = mock.Mock()
-
-        self.client.create_image = mock.Mock()
-        self.client.update_image = mock.Mock()
-        self.image_members_mock = self.app.client_manager.image.image_members
-        self.image_tags_mock = self.app.client_manager.image.image_tags
-
         # Get shortcut to the Mocks in identity client
         self.project_mock = self.app.client_manager.identity.projects
         self.project_mock.reset_mock()
         self.domain_mock = self.app.client_manager.identity.domains
         self.domain_mock.reset_mock()
-        self.volumes_mock = self.app.client_manager.volume.volumes
-        fake_body = {
-            'os-volume_upload_image':
-                {'volume_type': {'name': 'fake_type'}}}
-        self.volumes_mock.upload_to_image.return_value = (
-            200, fake_body)
-        self.volumes_mock.reset_mock()
 
     def setup_images_mock(self, count):
-        images = image_fakes.FakeImage.create_images(count=count)
+        images = image_fakes.create_images(count=count)
 
         return images
 
@@ -74,7 +55,7 @@ class TestImageCreate(TestImage):
     def setUp(self):
         super(TestImageCreate, self).setUp()
 
-        self.new_image = image_fakes.FakeImage.create_one_image()
+        self.new_image = image_fakes.create_one_image()
         self.client.create_image.return_value = self.new_image
 
         self.project_mock.get.return_value = self.project
@@ -191,7 +172,7 @@ class TestImageCreate(TestImage):
             '--protected',
             '--private',
             '--project', 'unexist_owner',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('container_format', 'ovf'),
@@ -203,7 +184,7 @@ class TestImageCreate(TestImage):
             ('public', False),
             ('private', True),
             ('project', 'unexist_owner'),
-            ('name', image_fakes.image_name),
+            ('name', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -306,108 +287,13 @@ class TestImageCreate(TestImage):
             use_import=True
         )
 
-    @mock.patch('osc_lib.utils.find_resource')
-    @mock.patch('openstackclient.image.v2.image.get_data_file')
-    def test_image_create_from_volume(self, mock_get_data_f, mock_get_vol):
-
-        fake_vol_id = 'fake-volume-id'
-        mock_get_data_f.return_value = (None, None)
-
-        class FakeVolume:
-            id = fake_vol_id
-
-        mock_get_vol.return_value = FakeVolume()
-
-        arglist = [
-            '--volume', fake_vol_id,
-            self.new_image.name,
-        ]
-        verifylist = [
-            ('name', self.new_image.name),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        columns, data = self.cmd.take_action(parsed_args)
-
-        self.volumes_mock.upload_to_image.assert_called_with(
-            fake_vol_id,
-            False,
-            self.new_image.name,
-            'bare',
-            'raw'
-        )
-
-    @mock.patch('osc_lib.utils.find_resource')
-    @mock.patch('openstackclient.image.v2.image.get_data_file')
-    def test_image_create_from_volume_fail(self, mock_get_data_f,
-                                           mock_get_vol):
-
-        fake_vol_id = 'fake-volume-id'
-        mock_get_data_f.return_value = (None, None)
-
-        class FakeVolume:
-            id = fake_vol_id
-
-        mock_get_vol.return_value = FakeVolume()
-
-        arglist = [
-            '--volume', fake_vol_id,
-            self.new_image.name,
-            '--public'
-        ]
-        verifylist = [
-            ('name', self.new_image.name),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        self.assertRaises(exceptions.CommandError, self.cmd.take_action,
-                          parsed_args)
-
-    @mock.patch('osc_lib.utils.find_resource')
-    @mock.patch('openstackclient.image.v2.image.get_data_file')
-    def test_image_create_from_volume_v31(self, mock_get_data_f,
-                                          mock_get_vol):
-
-        self.app.client_manager.volume.api_version = (
-            api_versions.APIVersion('3.1'))
-
-        fake_vol_id = 'fake-volume-id'
-        mock_get_data_f.return_value = (None, None)
-
-        class FakeVolume:
-            id = fake_vol_id
-
-        mock_get_vol.return_value = FakeVolume()
-
-        arglist = [
-            '--volume', fake_vol_id,
-            self.new_image.name,
-            '--public'
-        ]
-        verifylist = [
-            ('name', self.new_image.name),
-        ]
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        columns, data = self.cmd.take_action(parsed_args)
-
-        self.volumes_mock.upload_to_image.assert_called_with(
-            fake_vol_id,
-            False,
-            self.new_image.name,
-            'bare',
-            'raw',
-            visibility='public',
-            protected=False
-        )
-
 
 class TestAddProjectToImage(TestImage):
 
     project = identity_fakes.FakeProject.create_one_project()
     domain = identity_fakes.FakeDomain.create_one_domain()
-    _image = image_fakes.FakeImage.create_one_image()
-    new_member = image_fakes.FakeImage.create_one_image_member(
+    _image = image_fakes.create_one_image()
+    new_member = image_fakes.create_one_image_member(
         attrs={'image_id': _image.id,
                'member_id': project.id}
     )
@@ -539,7 +425,7 @@ class TestImageDelete(TestImage):
 
     def test_image_delete_multi_images_exception(self):
 
-        images = image_fakes.FakeImage.create_images(count=2)
+        images = image_fakes.create_images(count=2)
         arglist = [
             images[0].id,
             images[1].id,
@@ -571,7 +457,7 @@ class TestImageDelete(TestImage):
 
 class TestImageList(TestImage):
 
-    _image = image_fakes.FakeImage.create_one_image()
+    _image = image_fakes.create_one_image()
 
     columns = (
         'ID',
@@ -588,11 +474,7 @@ class TestImageList(TestImage):
     def setUp(self):
         super(TestImageList, self).setUp()
 
-        self.api_mock = mock.Mock()
-        self.api_mock.side_effect = [
-            [self._image], [],
-        ]
-        self.client.images = self.api_mock
+        self.client.images.side_effect = [[self._image], []]
 
         # Get the command object to test
         self.cmd = image.ListImage(self.app, None)
@@ -890,18 +772,13 @@ class TestImageList(TestImage):
 
     @mock.patch('osc_lib.utils.find_resource')
     def test_image_list_marker_option(self, fr_mock):
-        # tangchen: Since image_fakes.IMAGE is a dict, it cannot offer a .id
-        #           operation. Will fix this by using FakeImage class instead
-        #           of IMAGE dict.
         self.client.find_image = mock.Mock(return_value=self._image)
-#         fr_mock.return_value = mock.Mock()
-#         fr_mock.return_value.id = image_fakes.image_id
 
         arglist = [
-            '--marker', image_fakes.image_name,
+            '--marker', 'graven',
         ]
         verifylist = [
-            ('marker', image_fakes.image_name),
+            ('marker', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -910,7 +787,7 @@ class TestImageList(TestImage):
             marker=self._image.id,
         )
 
-        self.client.find_image.assert_called_with(image_fakes.image_name)
+        self.client.find_image.assert_called_with('graven')
 
     def test_image_list_name_option(self):
         arglist = [
@@ -973,8 +850,8 @@ class TestImageList(TestImage):
 class TestListImageProjects(TestImage):
 
     project = identity_fakes.FakeProject.create_one_project()
-    _image = image_fakes.FakeImage.create_one_image()
-    member = image_fakes.FakeImage.create_one_image_member(
+    _image = image_fakes.create_one_image()
+    member = image_fakes.create_one_image_member(
         attrs={'image_id': _image.id,
                'member_id': project.id}
     )
@@ -1024,7 +901,7 @@ class TestRemoveProjectImage(TestImage):
     def setUp(self):
         super(TestRemoveProjectImage, self).setUp()
 
-        self._image = image_fakes.FakeImage.create_one_image()
+        self._image = image_fakes.create_one_image()
         # This is the return value for utils.find_resource()
         self.client.find_image.return_value = self._image
 
@@ -1083,7 +960,7 @@ class TestImageSet(TestImage):
 
     project = identity_fakes.FakeProject.create_one_project()
     domain = identity_fakes.FakeDomain.create_one_domain()
-    _image = image_fakes.FakeImage.create_one_image({'tags': []})
+    _image = image_fakes.create_one_image({'tags': []})
 
     def setUp(self):
         super(TestImageSet, self).setUp()
@@ -1103,22 +980,24 @@ class TestImageSet(TestImage):
 
     def test_image_set_no_options(self):
         arglist = [
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
         ]
         verifylist = [
-            ('image', image_fakes.image_id)
+            ('image', '0f41529e-7c12-4de8-be2d-181abb825b3c')
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         result = self.cmd.take_action(parsed_args)
 
         self.assertIsNone(result)
-
-        self.image_members_mock.update.assert_not_called()
+        # we'll have called this but not set anything
+        self.app.client_manager.image.update_image.called_once_with(
+            self._image.id,
+        )
 
     def test_image_set_membership_option_accept(self):
-        membership = image_fakes.FakeImage.create_one_image_member(
-            attrs={'image_id': image_fakes.image_id,
+        membership = image_fakes.create_one_image_member(
+            attrs={'image_id': '0f41529e-7c12-4de8-be2d-181abb825b3c',
                    'member_id': self.project.id}
         )
         self.client.update_member.return_value = membership
@@ -1128,9 +1007,7 @@ class TestImageSet(TestImage):
             self._image.id,
         ]
         verifylist = [
-            ('accept', True),
-            ('reject', False),
-            ('pending', False),
+            ('membership', 'accepted'),
             ('image', self._image.id)
         ]
 
@@ -1148,21 +1025,19 @@ class TestImageSet(TestImage):
         self.client.update_image.assert_called_with(self._image.id)
 
     def test_image_set_membership_option_reject(self):
-        membership = image_fakes.FakeImage.create_one_image_member(
-            attrs={'image_id': image_fakes.image_id,
+        membership = image_fakes.create_one_image_member(
+            attrs={'image_id': '0f41529e-7c12-4de8-be2d-181abb825b3c',
                    'member_id': self.project.id}
         )
         self.client.update_member.return_value = membership
 
         arglist = [
             '--reject',
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
         ]
         verifylist = [
-            ('accept', False),
-            ('reject', True),
-            ('pending', False),
-            ('image', image_fakes.image_id)
+            ('membership', 'rejected'),
+            ('image', '0f41529e-7c12-4de8-be2d-181abb825b3c')
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1179,21 +1054,19 @@ class TestImageSet(TestImage):
         self.client.update_image.assert_called_with(self._image.id)
 
     def test_image_set_membership_option_pending(self):
-        membership = image_fakes.FakeImage.create_one_image_member(
-            attrs={'image_id': image_fakes.image_id,
+        membership = image_fakes.create_one_image_member(
+            attrs={'image_id': '0f41529e-7c12-4de8-be2d-181abb825b3c',
                    'member_id': self.project.id}
         )
         self.client.update_member.return_value = membership
 
         arglist = [
             '--pending',
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
         ]
         verifylist = [
-            ('accept', False),
-            ('reject', False),
-            ('pending', True),
-            ('image', image_fakes.image_id)
+            ('membership', 'pending'),
+            ('image', '0f41529e-7c12-4de8-be2d-181abb825b3c')
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1253,11 +1126,11 @@ class TestImageSet(TestImage):
 
         arglist = [
             '--project', 'unexist_owner',
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
         ]
         verifylist = [
             ('project', 'unexist_owner'),
-            ('image', image_fakes.image_id),
+            ('image', '0f41529e-7c12-4de8-be2d-181abb825b3c'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1269,14 +1142,14 @@ class TestImageSet(TestImage):
         arglist = [
             '--protected',
             '--private',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('protected', True),
             ('unprotected', False),
             ('public', False),
             ('private', True),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1297,14 +1170,14 @@ class TestImageSet(TestImage):
         arglist = [
             '--unprotected',
             '--public',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('protected', False),
             ('unprotected', True),
             ('public', True),
             ('private', False),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1325,11 +1198,11 @@ class TestImageSet(TestImage):
         arglist = [
             '--property', 'Alpha=1',
             '--property', 'Beta=2',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('properties', {'Alpha': '1', 'Beta': '2'}),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1354,7 +1227,7 @@ class TestImageSet(TestImage):
             '--os-distro', 'cpm',
             '--os-version', '2.2H',
             '--ramdisk-id', 'xyzpdq',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('architecture', 'z80'),
@@ -1363,7 +1236,7 @@ class TestImageSet(TestImage):
             ('os_distro', 'cpm'),
             ('os_version', '2.2H'),
             ('ramdisk_id', 'xyzpdq'),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1387,11 +1260,11 @@ class TestImageSet(TestImage):
     def test_image_set_tag(self):
         arglist = [
             '--tag', 'test-tag',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('tags', ['test-tag']),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1411,11 +1284,11 @@ class TestImageSet(TestImage):
         arglist = [
             '--tag', 'test-tag',
             '--activate',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('tags', ['test-tag']),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1439,11 +1312,11 @@ class TestImageSet(TestImage):
         arglist = [
             '--tag', 'test-tag',
             '--deactivate',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('tags', ['test-tag']),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1469,11 +1342,11 @@ class TestImageSet(TestImage):
         self.client.find_image.return_value = old_image
         arglist = [
             '--tag', 'test-tag',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('tags', ['test-tag']),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1495,11 +1368,11 @@ class TestImageSet(TestImage):
         self.client.find_image.return_value = old_image
         arglist = [
             '--tag', 'old1',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('tags', ['old1']),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1519,11 +1392,11 @@ class TestImageSet(TestImage):
 
         arglist = [
             '--visibility', '1-mile',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('visibility', '1-mile'),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1535,12 +1408,12 @@ class TestImageSet(TestImage):
         arglist = [
             '--min-disk', '0',
             '--min-ram', '0',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('min_disk', 0),
             ('min_ram', 0),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1561,13 +1434,13 @@ class TestImageSet(TestImage):
         arglist = [
             '--hidden',
             '--public',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('hidden', True),
             ('public', True),
             ('private', False),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1588,13 +1461,13 @@ class TestImageSet(TestImage):
         arglist = [
             '--unhidden',
             '--public',
-            image_fakes.image_name,
+            'graven',
         ]
         verifylist = [
             ('hidden', False),
             ('public', True),
             ('private', False),
-            ('image', image_fakes.image_name),
+            ('image', 'graven'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1614,10 +1487,10 @@ class TestImageSet(TestImage):
 
 class TestImageShow(TestImage):
 
-    new_image = image_fakes.FakeImage.create_one_image(
+    new_image = image_fakes.create_one_image(
         attrs={'size': 1000})
 
-    _data = image_fakes.FakeImage.create_one_image()
+    _data = image_fakes.create_one_image()
 
     columns = (
         'id', 'name', 'owner', 'protected', 'tags', 'visibility'
@@ -1642,10 +1515,10 @@ class TestImageShow(TestImage):
 
     def test_image_show(self):
         arglist = [
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
         ]
         verifylist = [
-            ('image', image_fakes.image_id),
+            ('image', '0f41529e-7c12-4de8-be2d-181abb825b3c'),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1654,7 +1527,7 @@ class TestImageShow(TestImage):
         # data to be shown.
         columns, data = self.cmd.take_action(parsed_args)
         self.client.find_image.assert_called_with(
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
             ignore_missing=False
         )
 
@@ -1696,7 +1569,7 @@ class TestImageUnset(TestImage):
         attrs['hw_rng_model'] = 'virtio'
         attrs['prop'] = 'test'
         attrs['prop2'] = 'fake'
-        self.image = image_fakes.FakeImage.create_one_image(attrs)
+        self.image = image_fakes.create_one_image(attrs)
 
         self.client.find_image.return_value = self.image
         self.client.remove_tag.return_value = self.image
@@ -1707,10 +1580,10 @@ class TestImageUnset(TestImage):
 
     def test_image_unset_no_options(self):
         arglist = [
-            image_fakes.image_id,
+            '0f41529e-7c12-4de8-be2d-181abb825b3c',
         ]
         verifylist = [
-            ('image', image_fakes.image_id)
+            ('image', '0f41529e-7c12-4de8-be2d-181abb825b3c')
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -1785,7 +1658,7 @@ class TestImageUnset(TestImage):
 
 class TestImageSave(TestImage):
 
-    image = image_fakes.FakeImage.create_one_image({})
+    image = image_fakes.create_one_image({})
 
     def setUp(self):
         super(TestImageSave, self).setUp()
