@@ -39,7 +39,6 @@ class TestFloatingIPPortForwarding(network_fakes.TestNetworkV2):
 class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
 
     def setUp(self):
-        project_id = ''
         super(TestCreateFloatingIPPortForwarding, self).setUp()
         self.new_port_forwarding = (
             network_fakes.FakeFloatingIPPortForwarding.
@@ -62,24 +61,24 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             self.app, self.namespace)
 
         self.columns = (
+            'description',
             'external_port',
             'floatingip_id',
             'id',
             'internal_ip_address',
             'internal_port',
             'internal_port_id',
-            'project_id',
             'protocol'
         )
 
         self.data = (
+            self.new_port_forwarding.description,
             self.new_port_forwarding.external_port,
             self.new_port_forwarding.floatingip_id,
             self.new_port_forwarding.id,
             self.new_port_forwarding.internal_ip_address,
             self.new_port_forwarding.internal_port,
             self.new_port_forwarding.internal_port_id,
-            project_id,
             self.new_port_forwarding.protocol,
         )
 
@@ -102,6 +101,8 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             self.new_port_forwarding.floatingip_id,
             '--internal-ip-address',
             self.new_port_forwarding.internal_ip_address,
+            '--description',
+            self.new_port_forwarding.description,
         ]
         verifylist = [
             ('port', self.new_port_forwarding.internal_port_id),
@@ -111,6 +112,7 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             ('floating_ip', self.new_port_forwarding.floatingip_id),
             ('internal_ip_address', self.new_port_forwarding.
                 internal_ip_address),
+            ('description', self.new_port_forwarding.description),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
@@ -126,6 +128,7 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
                     'internal_port_id': self.new_port_forwarding.
                     internal_port_id,
                     'protocol': self.new_port_forwarding.protocol,
+                    'description': self.new_port_forwarding.description,
                 })
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
@@ -251,7 +254,8 @@ class TestListFloatingIPPortForwarding(TestFloatingIPPortForwarding):
         'Internal IP Address',
         'Internal Port',
         'External Port',
-        'Protocol'
+        'Protocol',
+        'Description',
     )
 
     def setUp(self):
@@ -273,6 +277,7 @@ class TestListFloatingIPPortForwarding(TestFloatingIPPortForwarding):
                 port_forwarding.internal_port,
                 port_forwarding.external_port,
                 port_forwarding.protocol,
+                port_forwarding.description,
             ))
         self.network.floating_ip_port_forwardings = mock.Mock(
             return_value=self.port_forwardings
@@ -393,6 +398,7 @@ class TestSetFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             '--internal-protocol-port', '100',
             '--external-protocol-port', '200',
             '--protocol', 'tcp',
+            '--description', 'some description',
             self._port_forwarding.floatingip_id,
             self._port_forwarding.id,
         ]
@@ -402,6 +408,7 @@ class TestSetFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             ('internal_protocol_port', 100),
             ('external_protocol_port', 200),
             ('protocol', 'tcp'),
+            ('description', 'some description'),
             ('floating_ip', self._port_forwarding.floatingip_id),
             ('port_forwarding_id', self._port_forwarding.id),
         ]
@@ -415,6 +422,7 @@ class TestSetFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             'internal_port': 100,
             'external_port': 200,
             'protocol': 'tcp',
+            'description': 'some description',
         }
         self.network.update_floating_ip_port_forwarding.assert_called_with(
             self._port_forwarding.floatingip_id,
@@ -428,18 +436,17 @@ class TestShowFloatingIPPortForwarding(TestFloatingIPPortForwarding):
 
     # The port forwarding to show.
     columns = (
+        'description',
         'external_port',
         'floatingip_id',
         'id',
         'internal_ip_address',
         'internal_port',
         'internal_port_id',
-        'project_id',
         'protocol',
     )
 
     def setUp(self):
-        project_id = ''
         super(TestShowFloatingIPPortForwarding, self).setUp()
         self._port_forwarding = (
             network_fakes.FakeFloatingIPPortForwarding.
@@ -450,13 +457,13 @@ class TestShowFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             )
         )
         self.data = (
+            self._port_forwarding.description,
             self._port_forwarding.external_port,
             self._port_forwarding.floatingip_id,
             self._port_forwarding.id,
             self._port_forwarding.internal_ip_address,
             self._port_forwarding.internal_port,
             self._port_forwarding.internal_port_id,
-            project_id,
             self._port_forwarding.protocol,
         )
         self.network.find_floating_ip_port_forwarding = mock.Mock(
