@@ -26,6 +26,10 @@ from openstackclient.tests.unit.network.v2 import fakes as network_fakes
 from openstackclient.tests.unit import utils as tests_utils
 
 
+LIST_FIELDS_TO_RETRIEVE = ('id', 'name', 'mac_address', 'fixed_ips', 'status')
+LIST_FIELDS_TO_RETRIEVE_LONG = ('security_group_ids', 'device_owner', 'tags')
+
+
 class TestPort(network_fakes.TestNetworkV2):
 
     def setUp(self):
@@ -50,6 +54,7 @@ class TestPort(network_fakes.TestNetworkV2):
             'description',
             'device_id',
             'device_owner',
+            'device_profile',
             'dns_assignment',
             'dns_domain',
             'dns_name',
@@ -59,14 +64,15 @@ class TestPort(network_fakes.TestNetworkV2):
             'mac_address',
             'name',
             'network_id',
+            'numa_affinity_policy',
             'port_security_enabled',
             'project_id',
+            'propagate_uplink_status',
             'qos_network_policy_id',
             'qos_policy_id',
             'security_group_ids',
             'status',
             'tags',
-            'uplink_status_propagation',
         )
 
         data = (
@@ -81,6 +87,7 @@ class TestPort(network_fakes.TestNetworkV2):
             fake_port.description,
             fake_port.device_id,
             fake_port.device_owner,
+            fake_port.device_profile,
             format_columns.ListDictColumn(fake_port.dns_assignment),
             fake_port.dns_domain,
             fake_port.dns_name,
@@ -90,14 +97,15 @@ class TestPort(network_fakes.TestNetworkV2):
             fake_port.mac_address,
             fake_port.name,
             fake_port.network_id,
+            fake_port.numa_affinity_policy,
             fake_port.port_security_enabled,
             fake_port.project_id,
+            fake_port.propagate_uplink_status,
             fake_port.qos_network_policy_id,
             fake_port.qos_policy_id,
             format_columns.ListColumn(fake_port.security_group_ids),
             fake_port.status,
             format_columns.ListColumn(fake_port.tags),
-            fake_port.uplink_status_propagation,
         )
 
         return columns, data
@@ -119,6 +127,7 @@ class TestCreatePort(TestPort):
         self.network.find_network = mock.Mock(return_value=fake_net)
         self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet()
         self.network.find_subnet = mock.Mock(return_value=self.fake_subnet)
+        self.network.find_extension = mock.Mock(return_value=[])
         # Get the command object to test
         self.cmd = port.CreatePort(self.app, self.namespace)
 
@@ -144,7 +153,7 @@ class TestCreatePort(TestPort):
         self.assertFalse(self.network.set_tags.called)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_full_options(self):
         arglist = [
@@ -202,7 +211,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_invalid_json_binding_profile(self):
         arglist = [
@@ -253,7 +262,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_security_group(self):
         secgroup = network_fakes.FakeSecurityGroup.create_one_security_group()
@@ -282,7 +291,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_dns_name(self):
         arglist = [
@@ -308,7 +317,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_security_groups(self):
         sg_1 = network_fakes.FakeSecurityGroup.create_one_security_group()
@@ -338,7 +347,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_no_security_groups(self):
         arglist = [
@@ -364,7 +373,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_no_fixed_ips(self):
         arglist = [
@@ -390,7 +399,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_allowed_address_pair_ipaddr(self):
         pairs = [{'ip_address': '192.168.1.123'},
@@ -420,7 +429,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_allowed_address_pair(self):
         pairs = [{'ip_address': '192.168.1.123',
@@ -456,7 +465,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_with_qos(self):
         qos_policy = network_fakes.FakeNetworkQosPolicy.create_one_qos_policy()
@@ -484,7 +493,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_port_security_enabled(self):
         arglist = [
@@ -534,7 +543,7 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
-    def _test_create_with_tag(self, add_tags=True):
+    def _test_create_with_tag(self, add_tags=True, add_tags_in_post=True):
         arglist = [
             '--network', self._port.network_id,
             'test-port',
@@ -553,28 +562,59 @@ class TestCreatePort(TestPort):
         else:
             verifylist.append(('no_tag', True))
 
+        self.network.find_extension = mock.Mock(return_value=add_tags_in_post)
+
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = (self.cmd.take_action(parsed_args))
 
-        self.network.create_port.assert_called_once_with(
-            admin_state_up=True,
-            network_id=self._port.network_id,
-            name='test-port'
-        )
-        if add_tags:
-            self.network.set_tags.assert_called_once_with(
-                self._port,
-                tests_utils.CompareBySet(['red', 'blue']))
+        args = {
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'name': 'test-port',
+        }
+        if add_tags_in_post:
+            if add_tags:
+                args['tags'] = sorted(['red', 'blue'])
+            else:
+                args['tags'] = []
+            self.network.create_port.assert_called_once()
+            # Now we need to verify if arguments to call create_port are as
+            # expected,
+            # But we can't simply use assert_called_once_with() method because
+            # duplicates from 'tags' are removed with
+            # list(set(parsed_args.tags)) and that don't quarantee order of
+            # tags list which is used to call create_port().
+            create_port_call_kwargs = self.network.create_port.call_args[1]
+            create_port_call_kwargs['tags'] = sorted(
+                create_port_call_kwargs['tags'])
+            self.assertDictEqual(args, create_port_call_kwargs)
         else:
-            self.assertFalse(self.network.set_tags.called)
+            self.network.create_port.assert_called_once_with(
+                admin_state_up=True,
+                network_id=self._port.network_id,
+                name='test-port'
+            )
+            if add_tags:
+                self.network.set_tags.assert_called_once_with(
+                    self._port,
+                    tests_utils.CompareBySet(['red', 'blue']))
+            else:
+                self.assertFalse(self.network.set_tags.called)
+
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
-        self._test_create_with_tag(add_tags=True)
+        self._test_create_with_tag(add_tags=True, add_tags_in_post=True)
 
     def test_create_with_no_tag(self):
-        self._test_create_with_tag(add_tags=False)
+        self._test_create_with_tag(add_tags=False, add_tags_in_post=True)
+
+    def test_create_with_tags_using_put(self):
+        self._test_create_with_tag(add_tags=True, add_tags_in_post=False)
+
+    def test_create_with_no_tag_using_put(self):
+        self._test_create_with_tag(add_tags=False, add_tags_in_post=False)
 
     def _test_create_with_uplink_status_propagation(self, enable=True):
         arglist = [
@@ -605,7 +645,7 @@ class TestCreatePort(TestPort):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_uplink_status_propagation_enabled(self):
         self._test_create_with_uplink_status_propagation(enable=True)
@@ -655,6 +695,77 @@ class TestCreatePort(TestPort):
             'name': 'test-port',
         })
 
+    def _test_create_with_numa_affinity_policy(self, policy=None):
+        arglist = [
+            '--network', self._port.network_id,
+            'test-port',
+        ]
+        if policy:
+            arglist += ['--numa-policy-%s' % policy]
+
+        numa_affinity_policy = None if not policy else policy
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('name', 'test-port'),
+        ]
+        if policy:
+            verifylist.append(('numa_policy_%s' % policy, True))
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        create_args = {
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'name': 'test-port',
+        }
+        if numa_affinity_policy:
+            create_args['numa_affinity_policy'] = numa_affinity_policy
+        self.network.create_port.assert_called_once_with(**create_args)
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, data)
+
+    def test_create_with_numa_affinity_policy_required(self):
+        self._test_create_with_numa_affinity_policy(policy='required')
+
+    def test_create_with_numa_affinity_policy_preferred(self):
+        self._test_create_with_numa_affinity_policy(policy='preferred')
+
+    def test_create_with_numa_affinity_policy_legacy(self):
+        self._test_create_with_numa_affinity_policy(policy='legacy')
+
+    def test_create_with_numa_affinity_policy_null(self):
+        self._test_create_with_numa_affinity_policy()
+
+    def test_create_with_device_profile(self):
+        arglist = [
+            '--network', self._port.network_id,
+            '--device-profile', 'cyborg_device_profile_1',
+            'test-port',
+        ]
+
+        verifylist = [
+            ('network', self._port.network_id,),
+            ('device_profile', self._port.device_profile,),
+            ('name', 'test-port'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        create_args = {
+            'admin_state_up': True,
+            'network_id': self._port.network_id,
+            'name': 'test-port',
+            'device_profile': 'cyborg_device_profile_1',
+        }
+        self.network.create_port.assert_called_once_with(**create_args)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, data)
+
 
 class TestDeletePort(TestPort):
 
@@ -805,9 +916,10 @@ class TestListPort(TestPort):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.ports.assert_called_once_with()
+        self.network.ports.assert_called_once_with(
+            fields=LIST_FIELDS_TO_RETRIEVE)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_router_opt(self):
         arglist = [
@@ -823,10 +935,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'device_id': 'fake-router-id'
+            'device_id': 'fake-router-id',
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     @mock.patch.object(utils, 'find_resource')
     def test_port_list_with_server_option(self, mock_find):
@@ -843,10 +956,11 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
         self.network.ports.assert_called_once_with(
-            device_id=fake_server.id)
+            device_id=fake_server.id,
+            fields=LIST_FIELDS_TO_RETRIEVE)
         mock_find.assert_called_once_with(mock.ANY, 'fake-server-name')
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_device_id_opt(self):
         arglist = [
@@ -862,10 +976,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'device_id': self._ports[0].device_id
+            'device_id': self._ports[0].device_id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_device_owner_opt(self):
         arglist = [
@@ -881,10 +996,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'device_owner': self._ports[0].device_owner
+            'device_owner': self._ports[0].device_owner,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_all_opt(self):
         arglist = [
@@ -909,10 +1025,11 @@ class TestListPort(TestPort):
             'device_owner': self._ports[0].device_owner,
             'device_id': 'fake-router-id',
             'network_id': 'fake-network-id',
-            'mac_address': self._ports[0].mac_address
+            'mac_address': self._ports[0].mac_address,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_mac_address_opt(self):
         arglist = [
@@ -928,10 +1045,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'mac_address': self._ports[0].mac_address
+            'mac_address': self._ports[0].mac_address,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
         })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opt_ip_address(self):
         ip_address = self._ports[0].fixed_ips[0]['ip_address']
@@ -947,9 +1065,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'fixed_ips': ['ip_address=%s' % ip_address]})
+            'fixed_ips': ['ip_address=%s' % ip_address],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opt_ip_address_substr(self):
         ip_address_ss = self._ports[0].fixed_ips[0]['ip_address'][:-1]
@@ -965,9 +1085,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'fixed_ips': ['ip_address_substr=%s' % ip_address_ss]})
+            'fixed_ips': ['ip_address_substr=%s' % ip_address_ss],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opt_subnet_id(self):
         subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
@@ -985,9 +1107,11 @@ class TestListPort(TestPort):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
-            'fixed_ips': ['subnet_id=%s' % subnet_id]})
+            'fixed_ips': ['subnet_id=%s' % subnet_id],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ip_opts(self):
         subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
@@ -1009,9 +1133,11 @@ class TestListPort(TestPort):
 
         self.network.ports.assert_called_once_with(**{
             'fixed_ips': ['subnet_id=%s' % subnet_id,
-                          'ip_address=%s' % ip_address]})
+                          'ip_address=%s' % ip_address],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_fixed_ips(self):
         subnet_id = self._ports[0].fixed_ips[0]['subnet_id']
@@ -1025,17 +1151,21 @@ class TestListPort(TestPort):
                           {'ip-address': ip_address}])
         ]
 
-        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet(
-            {'id': subnet_id})
+        self.fake_subnet = network_fakes.FakeSubnet.create_one_subnet({
+            'id': subnet_id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.network.find_subnet = mock.Mock(return_value=self.fake_subnet)
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.ports.assert_called_once_with(**{
             'fixed_ips': ['subnet_id=%s' % subnet_id,
-                          'ip_address=%s' % ip_address]})
+                          'ip_address=%s' % ip_address],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        })
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_list_port_with_long(self):
         arglist = [
@@ -1050,9 +1180,29 @@ class TestListPort(TestPort):
 
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.network.ports.assert_called_once_with()
+        self.network.ports.assert_called_once_with(
+            fields=LIST_FIELDS_TO_RETRIEVE + LIST_FIELDS_TO_RETRIEVE_LONG)
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
+
+    def test_port_list_host(self):
+        arglist = [
+            '--host', 'foobar',
+        ]
+        verifylist = [
+            ('host', 'foobar'),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {
+            'binding:host_id': 'foobar',
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
+
+        self.network.ports.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_project(self):
         project = identity_fakes.FakeProject.create_one_project()
@@ -1066,11 +1216,14 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {
+            'project_id': project.id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
 
         self.network.ports.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_port_list_project_domain(self):
         project = identity_fakes.FakeProject.create_one_project()
@@ -1086,11 +1239,34 @@ class TestListPort(TestPort):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {
+            'project_id': project.id,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
 
         self.network.ports.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
+
+    def test_port_list_name(self):
+        test_name = "fakename"
+        arglist = [
+            '--name', test_name,
+        ]
+        verifylist = [
+            ('name', test_name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {
+            'name': test_name,
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
+
+        self.network.ports.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -1112,10 +1288,31 @@ class TestListPort(TestPort):
             **{'tags': 'red,blue',
                'any_tags': 'red,green',
                'not_tags': 'orange,yellow',
-               'not_any_tags': 'black,white'}
+               'not_any_tags': 'black,white',
+               'fields': LIST_FIELDS_TO_RETRIEVE}
         )
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
+
+    def test_port_list_security_group(self):
+        arglist = [
+            '--security-group', 'sg-id1',
+            '--security-group', 'sg-id2',
+        ]
+        verifylist = [
+            ('security_groups', ['sg-id1', 'sg-id2']),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {
+            'security_groups': ['sg-id1', 'sg-id2'],
+            'fields': LIST_FIELDS_TO_RETRIEVE,
+        }
+
+        self.network.ports.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
 
 
 class TestSetPort(TestPort):
@@ -1530,6 +1727,27 @@ class TestSetPort(TestPort):
         self.network.update_port.assert_called_once_with(self._port, **attrs)
         self.assertIsNone(result)
 
+    def test_set_port_extra_dhcp_option(self):
+        arglist = [
+            '--extra-dhcp-option', 'name=foo,value=bar',
+            self._port.name,
+        ]
+        verifylist = [
+            ('extra_dhcp_options', [{'name': 'foo',
+                                     'value': 'bar'}]),
+            ('port', self._port.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'extra_dhcp_opts': [{'opt_name': 'foo',
+                                 'opt_value': 'bar'}],
+        }
+        self.network.update_port.assert_called_once_with(self._port, **attrs)
+        self.assertIsNone(result)
+
     def test_set_port_security_enabled(self):
         arglist = [
             '--enable-port-security',
@@ -1652,6 +1870,32 @@ class TestSetPort(TestPort):
     def test_set_with_no_tag(self):
         self._test_set_tags(with_tags=False)
 
+    def _test_create_with_numa_affinity_policy(self, policy):
+        arglist = [
+            '--numa-policy-%s' % policy,
+            self._port.id,
+        ]
+        verifylist = [
+            ('numa_policy_%s' % policy, True),
+            ('port', self._port.id,)
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.network.update_port.assert_called_once_with(
+            self._port, **{'numa_affinity_policy': policy})
+
+    def test_create_with_numa_affinity_policy_required(self):
+        self._test_create_with_numa_affinity_policy('required')
+
+    def test_create_with_numa_affinity_policy_preferred(self):
+        self._test_create_with_numa_affinity_policy('preferred')
+
+    def test_create_with_numa_affinity_policy_legacy(self):
+        self._test_create_with_numa_affinity_policy('legacy')
+
 
 class TestShowPort(TestPort):
 
@@ -1689,7 +1933,7 @@ class TestShowPort(TestPort):
             self._port.name, ignore_missing=False)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
 
 class TestUnsetPort(TestPort):
@@ -1718,6 +1962,7 @@ class TestUnsetPort(TestPort):
             'subnet=042eb10a-3a18-4658-ab-cf47c8d03152,ip-address=1.0.0.0',
             '--binding-profile', 'Superman',
             '--qos-policy',
+            '--host',
             self._testport.name,
         ]
         verifylist = [
@@ -1726,6 +1971,7 @@ class TestUnsetPort(TestPort):
                 'ip-address': '1.0.0.0'}]),
             ('binding_profile', ['Superman']),
             ('qos_policy', True),
+            ('host', True)
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1736,7 +1982,8 @@ class TestUnsetPort(TestPort):
                 'subnet_id': '042eb10a-3a18-4658-ab-cf47c8d03152',
                 'ip_address': '0.0.0.1'}],
             'binding:profile': {'batman': 'Joker'},
-            'qos_policy_id': None
+            'qos_policy_id': None,
+            'binding:host_id': None
         }
         self.network.update_port.assert_called_once_with(
             self._testport, **attrs)
@@ -1907,3 +2154,26 @@ class TestUnsetPort(TestPort):
 
     def test_unset_with_all_tag(self):
         self._test_unset_tags(with_tags=False)
+
+    def test_unset_numa_affinity_policy(self):
+        _fake_port = network_fakes.FakePort.create_one_port(
+            {'numa_affinity_policy': 'required'})
+        self.network.find_port = mock.Mock(return_value=_fake_port)
+        arglist = [
+            '--numa-policy',
+            _fake_port.name,
+        ]
+        verifylist = [
+            ('numa_policy', True),
+            ('port', _fake_port.name),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'numa_affinity_policy': None,
+        }
+
+        self.network.update_port.assert_called_once_with(_fake_port, **attrs)
+        self.assertIsNone(result)
