@@ -141,7 +141,7 @@ class TestCreateRouter(TestRouter):
         new_router.ha,
         new_router.id,
         new_router.name,
-        new_router.tenant_id,
+        new_router.project_id,
         router.RoutesColumn(new_router.routes),
         new_router.status,
         format_columns.ListColumn(new_router.tags),
@@ -186,6 +186,43 @@ class TestCreateRouter(TestRouter):
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, data)
 
+    def test_create_with_gateway(self):
+        _network = network_fakes.FakeNetwork.create_one_network()
+        _subnet = network_fakes.FakeSubnet.create_one_subnet()
+        self.network.find_network = mock.Mock(return_value=_network)
+        self.network.find_subnet = mock.Mock(return_value=_subnet)
+        arglist = [
+            self.new_router.name,
+            '--external-gateway', _network.name,
+            '--enable-snat',
+            '--fixed-ip', 'ip-address=2001:db8::1'
+        ]
+        verifylist = [
+            ('name', self.new_router.name),
+            ('enable', True),
+            ('distributed', False),
+            ('ha', False),
+            ('external_gateway', _network.name),
+            ('enable_snat', True),
+            ('fixed_ip', [{'ip-address': '2001:db8::1'}]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.network.create_router.assert_called_once_with(**{
+            'admin_state_up': True,
+            'name': self.new_router.name,
+            'external_gateway_info': {
+                'network_id': _network.id,
+                'enable_snat': True,
+                'external_fixed_ips': [{'ip_address': '2001:db8::1'}],
+            },
+        })
+        self.assertFalse(self.network.set_tags.called)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, data)
+
     def _test_create_with_ha_options(self, option, ha):
         arglist = [
             option,
@@ -423,7 +460,7 @@ class TestListRouter(TestRouter):
             r.name,
             r.status,
             router.AdminStateColumn(r.admin_state_up),
-            r.tenant_id,
+            r.project_id,
             r.distributed,
             r.ha,
         ))
@@ -619,7 +656,7 @@ class TestListRouter(TestRouter):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
@@ -639,7 +676,7 @@ class TestListRouter(TestRouter):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
@@ -1364,7 +1401,7 @@ class TestShowRouter(TestRouter):
         _router.id,
         router.RouterInfoColumn(_router.interfaces_info),
         _router.name,
-        _router.tenant_id,
+        _router.project_id,
         router.RoutesColumn(_router.routes),
         _router.status,
         format_columns.ListColumn(_router.tags),
