@@ -44,7 +44,7 @@ class TestCreateSubnet(TestSubnet):
         # An IPv4 subnet to be created with mostly default values
         self._subnet = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'tenant_id': self.project.id,
+                'project_id': self.project.id,
             }
         )
 
@@ -55,7 +55,7 @@ class TestCreateSubnet(TestSubnet):
         # An IPv4 subnet to be created using a specific subnet pool
         self._subnet_from_pool = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'tenant_id': self.project.id,
+                'project_id': self.project.id,
                 'subnetpool_id': self._subnet_pool.id,
                 'dns_nameservers': ['8.8.8.8',
                                     '8.8.4.4'],
@@ -71,7 +71,7 @@ class TestCreateSubnet(TestSubnet):
         # An IPv6 subnet to be created with most options specified
         self._subnet_ipv6 = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'tenant_id': self.project.id,
+                'project_id': self.project.id,
                 'cidr': 'fe80:0:0:a00a::/64',
                 'enable_dhcp': True,
                 'dns_nameservers': ['fe80:27ff:a00a:f00f::ffff',
@@ -255,7 +255,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_from_subnet_pool_options(self):
         # Mock SDK calls for this test.
@@ -317,7 +317,7 @@ class TestCreateSubnet(TestSubnet):
             'service_types': self._subnet_from_pool.service_types,
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data_subnet_pool, data)
+        self.assertCountEqual(self.data_subnet_pool, data)
 
     def test_create_options_subnet_range_ipv6(self):
         # Mock SDK calls for this test.
@@ -390,7 +390,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data_ipv6, data)
+        self.assertCountEqual(self.data_ipv6, data)
 
     def test_create_with_network_segment(self):
         # Mock SDK calls for this test.
@@ -424,7 +424,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_description(self):
         # Mock SDK calls for this test.
@@ -458,7 +458,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def _test_create_with_dns(self, publish_dns=True):
         arglist = [
@@ -490,7 +490,7 @@ class TestCreateSubnet(TestSubnet):
             dns_publish_fixed_ip=publish_dns,
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_dns(self):
         self._test_create_with_dns(publish_dns=True)
@@ -535,7 +535,7 @@ class TestCreateSubnet(TestSubnet):
         else:
             self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -661,7 +661,7 @@ class TestListSubnet(TestSubnet):
             subnet.name,
             subnet.network_id,
             subnet.cidr,
-            subnet.tenant_id,
+            subnet.project_id,
             subnet.enable_dhcp,
             format_columns.ListColumn(subnet.dns_nameservers),
             subnet_v2.AllocationPoolsColumn(subnet.allocation_pools),
@@ -691,7 +691,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_long(self):
         arglist = [
@@ -706,7 +706,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertListItemEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
     def test_subnet_list_ip_version(self):
         arglist = [
@@ -722,7 +722,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_dhcp(self):
         arglist = [
@@ -738,7 +738,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_no_dhcp(self):
         arglist = [
@@ -754,7 +754,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_service_type(self):
         arglist = [
@@ -769,7 +769,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_project(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -783,11 +783,11 @@ class TestListSubnet(TestSubnet):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_service_type_multiple(self):
         arglist = [
@@ -805,7 +805,7 @@ class TestListSubnet(TestSubnet):
                                      'network:floatingip_agent_gateway']}
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -821,11 +821,11 @@ class TestListSubnet(TestSubnet):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_network(self):
         network = network_fakes.FakeNetwork.create_one_network()
@@ -843,7 +843,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_gateway(self):
         subnet = network_fakes.FakeSubnet.create_one_subnet()
@@ -861,7 +861,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_name(self):
         subnet = network_fakes.FakeSubnet.create_one_subnet()
@@ -879,7 +879,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_subnet_range(self):
         subnet = network_fakes.FakeSubnet.create_one_subnet()
@@ -897,7 +897,49 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertListItemEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
+
+    def test_subnet_list_subnetpool_by_name(self):
+        subnet_pool = network_fakes.FakeSubnetPool.create_one_subnet_pool()
+        subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'subnetpool_id': subnet_pool.id})
+        self.network.find_network = mock.Mock(return_value=subnet)
+        self.network.find_subnet_pool = mock.Mock(return_value=subnet_pool)
+        arglist = [
+            '--subnet-pool', subnet_pool.name,
+        ]
+        verifylist = [
+            ('subnet_pool', subnet_pool.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'subnetpool_id': subnet_pool.id}
+
+        self.network.subnets.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertItemsEqual(self.data, list(data))
+
+    def test_subnet_list_subnetpool_by_id(self):
+        subnet_pool = network_fakes.FakeSubnetPool.create_one_subnet_pool()
+        subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'subnetpool_id': subnet_pool.id})
+        self.network.find_network = mock.Mock(return_value=subnet)
+        self.network.find_subnet_pool = mock.Mock(return_value=subnet_pool)
+        arglist = [
+            '--subnet-pool', subnet_pool.id,
+        ]
+        verifylist = [
+            ('subnet_pool', subnet_pool.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'subnetpool_id': subnet_pool.id}
+
+        self.network.subnets.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertItemsEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -1205,7 +1247,7 @@ class TestShowSubnet(TestSubnet):
         _subnet.ipv6_ra_mode,
         _subnet.name,
         _subnet.network_id,
-        _subnet.tenant_id,
+        _subnet.project_id,
         _subnet.segment_id,
         format_columns.ListColumn(_subnet.service_types),
         _subnet.subnetpool_id,
@@ -1244,7 +1286,7 @@ class TestShowSubnet(TestSubnet):
             self._subnet.name, ignore_missing=False)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
 
 class TestUnsetSubnet(TestSubnet):
@@ -1264,6 +1306,7 @@ class TestUnsetSubnet(TestSubnet):
                                    'end': '8.8.8.170'}],
              'service_types': ['network:router_gateway',
                                'network:floatingip_agent_gateway'],
+             'gateway_ip': 'fe80::a00a:0:c0de:0:1',
              'tags': ['green', 'red'], })
         self.network.find_subnet = mock.Mock(return_value=self._testsubnet)
         self.network.update_subnet = mock.Mock(return_value=None)
@@ -1277,6 +1320,7 @@ class TestUnsetSubnet(TestSubnet):
             '--host-route', 'destination=10.30.30.30/24,gateway=10.30.30.1',
             '--allocation-pool', 'start=8.8.8.100,end=8.8.8.150',
             '--service-type', 'network:router_gateway',
+            '--gateway',
             self._testsubnet.name,
         ]
         verifylist = [
@@ -1286,6 +1330,7 @@ class TestUnsetSubnet(TestSubnet):
             ('allocation_pools', [{
                 'start': '8.8.8.100', 'end': '8.8.8.150'}]),
             ('service_types', ['network:router_gateway']),
+            ('gateway', True),
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1297,6 +1342,7 @@ class TestUnsetSubnet(TestSubnet):
                 "destination": "10.20.20.0/24", "nexthop": "10.20.20.1"}],
             'allocation_pools': [{'start': '8.8.8.160', 'end': '8.8.8.170'}],
             'service_types': ['network:floatingip_agent_gateway'],
+            'gateway_ip': None,
         }
         self.network.update_subnet.assert_called_once_with(
             self._testsubnet, **attrs)
