@@ -14,9 +14,10 @@
 #
 
 import copy
+from unittest import mock
+from unittest.mock import call
 
-import mock
-from mock import call
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
 from osc_lib import utils
 
@@ -38,7 +39,7 @@ class TestQos(volume_fakes.TestVolumev1):
 
 class TestQosAssociate(TestQos):
 
-    volume_type = volume_fakes.FakeType.create_one_type()
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
     qos_spec = volume_fakes.FakeQos.create_one_qos()
 
     def setUp(self):
@@ -85,7 +86,7 @@ class TestQosCreate(TestQos):
             self.new_qos_spec.consumer,
             self.new_qos_spec.id,
             self.new_qos_spec.name,
-            utils.format_dict(self.new_qos_spec.specs)
+            format_columns.DictColumn(self.new_qos_spec.specs)
         )
         self.qos_mock.create.return_value = self.new_qos_spec
         # Get the command object to test
@@ -108,7 +109,7 @@ class TestQosCreate(TestQos):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_qos_create_with_consumer(self):
         arglist = [
@@ -128,7 +129,7 @@ class TestQosCreate(TestQos):
             {'consumer': self.new_qos_spec.consumer}
         )
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_qos_create_with_properties(self):
         arglist = [
@@ -154,7 +155,7 @@ class TestQosCreate(TestQos):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
 
 class TestQosDelete(TestQos):
@@ -262,7 +263,7 @@ class TestQosDelete(TestQos):
 
 class TestQosDisassociate(TestQos):
 
-    volume_type = volume_fakes.FakeType.create_one_type()
+    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
     qos_spec = volume_fakes.FakeQos.create_one_qos()
 
     def setUp(self):
@@ -326,8 +327,8 @@ class TestQosList(TestQos):
             q.id,
             q.name,
             q.consumer,
-            qos_association.name,
-            utils.format_dict(q.specs),
+            format_columns.ListColumn([qos_association.name]),
+            format_columns.DictColumn(q.specs),
         ))
 
     def setUp(self):
@@ -349,7 +350,7 @@ class TestQosList(TestQos):
         self.qos_mock.list.assert_called_with()
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_qos_list_no_association(self):
         self.qos_mock.reset_mock()
@@ -373,10 +374,10 @@ class TestQosList(TestQos):
             self.qos_specs[1].id,
             self.qos_specs[1].name,
             self.qos_specs[1].consumer,
-            None,
-            utils.format_dict(self.qos_specs[1].specs),
+            format_columns.ListColumn(None),
+            format_columns.DictColumn(self.qos_specs[1].specs),
         )
-        self.assertEqual(ex_data, list(data))
+        self.assertCountEqual(ex_data, list(data))
 
 
 class TestQosSet(TestQos):
@@ -447,13 +448,13 @@ class TestQosShow(TestQos):
         )
         self.assertEqual(collist, columns)
         datalist = (
-            self.qos_association.name,
+            format_columns.ListColumn([self.qos_association.name]),
             self.qos_spec.consumer,
             self.qos_spec.id,
             self.qos_spec.name,
-            utils.format_dict(self.qos_spec.specs),
+            format_columns.DictColumn(self.qos_spec.specs),
         )
-        self.assertEqual(datalist, tuple(data))
+        self.assertCountEqual(datalist, tuple(data))
 
 
 class TestQosUnset(TestQos):
