@@ -327,6 +327,13 @@ class ListVolume(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
+        parser.add_argument(
+            '--offset',
+            type=int,
+            action=parseractions.NonNegativeAction,
+            metavar='<offset>',
+            help=_('Index from which to start listing volumes'),
+        )
         parser.add_argument(
             '--limit',
             type=int,
@@ -395,6 +402,9 @@ class ListVolume(command.Lister):
             'status': parsed_args.status,
         }
 
+        if parsed_args.offset:
+            search_opts['offset'] = parsed_args.offset
+
         data = volume_client.volumes.list(
             search_opts=search_opts,
             limit=parsed_args.limit,
